/*-
 * %%----------------------------------------------------------------------------------------------
 * DLCM Technology - DLCM Portal - app.module.ts
 * SPDX-License-Identifier: GPL-2.0-or-later
 * %----------------------------------------------------------------------------------------------%
 * Copyright (C) 2017 - 2022 University of Geneva
 * %----------------------------------------------------------------------------------------------%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-2.0.html>.
 * ----------------------------------------------------------------------------------------------%%
 */

import {
  HTTP_INTERCEPTORS,
  HttpClient,
  HttpClientModule,
} from "@angular/common/http";
import {
  APP_INITIALIZER,
  ErrorHandler,
  NgModule,
} from "@angular/core";
import {ReactiveFormsModule} from "@angular/forms";
import {
  MAT_MOMENT_DATE_ADAPTER_OPTIONS,
  MAT_MOMENT_DATE_FORMATS,
  MomentDateAdapter,
} from "@angular/material-moment-adapter";
import {
  DateAdapter,
  MAT_DATE_FORMATS,
  MAT_DATE_LOCALE,
} from "@angular/material/core";
import {MatPaginatorIntl} from "@angular/material/paginator";
import {MatSnackBar} from "@angular/material/snack-bar";
import {BrowserModule} from "@angular/platform-browser";
import {BrowserAnimationsModule} from "@angular/platform-browser/animations";
import {ServiceWorkerModule} from "@angular/service-worker";
import {AppRoutingModule} from "@app/app-routing.module";
import {FooterContainer} from "@app/components/container/footer/footer.container";
import {PrivacyPolicyTermsOfUseApprovalDialog} from "@app/components/dialogs/privacy-policy-terms-of-use-approval/privacy-policy-terms-of-use-approval.dialog";
import {UserDialog} from "@app/components/dialogs/user/user.dialog";
import {GuidedTourMenuPresentational} from "@app/components/presentationals/guided-tour-menu/guided-tour-menu.presentational";
import {BurgerMenuPresentational} from "@app/components/presentationals/main-toolbar/burger-menu/burger-menu.presentational";
import {MainToolbarMobilePresentational} from "@app/components/presentationals/main-toolbar/main-toolbar-mobile/main-toolbar-mobile.presentational";
import {MainToolbarPresentational} from "@app/components/presentationals/main-toolbar/main-toolbar/main-toolbar.presentational";
import {UserFormPresentational} from "@app/components/presentationals/user-form/user-form.presentational";
import {UserMenuPresentational} from "@app/components/presentationals/user-menu/user-menu.presentational";
import {cookieConsentPreferences} from "@app/cookie-consent-preferences";
import {dataTableComponentSolidify} from "@app/data-table-component-solidify";
import {icons} from "@app/icons";
import {InMemoryStorage} from "@app/in-memory.storage";
import {labelTranslateSolidify} from "@app/label-translate-solidify";
import {SharedModule} from "@app/shared/shared.module";
import {AppState} from "@app/stores/app.state";
import {AppArchiveAclState} from "@app/stores/archive-acl/app-archive-acl.state";
import {AppAuthorizedOrganizationalUnitState} from "@app/stores/authorized-organizational-unit/app-authorized-organizational-unit.state";
import {AppBannerState} from "@app/stores/banner/app-banner.state";
import {AppCarouselState} from "@app/stores/carousel/app-carousel.state";
import {AppCartState} from "@app/stores/cart/app-cart.state";
import {AppCartArchiveState} from "@app/stores/cart/archive/app-cart-archive.state";
import {AppCartDipState} from "@app/stores/cart/dip/app-cart-dip.state";
import {AppCartDipDataFileState} from "@app/stores/cart/dip/data-file/app-cart-dip-data-file.state";
import {AppCartOrderState} from "@app/stores/cart/order/app-cart-order.state";
import {AppNotificationInboxState} from "@app/stores/notification-inbox/app-notification-inbox.state";
import {AppPersonState} from "@app/stores/person/app-person.state";
import {AppPersonNotificationTypeState} from "@app/stores/person/notification-type/app-person-notification-type.state";
import {AppSystemPropertyState} from "@app/stores/system-property/app-system-property.state";
import {AppTocState} from "@app/stores/toc/app-toc.state";
import {AppUserState} from "@app/stores/user/app-user.state";
import {environment} from "@environments/environment";
import {FormlyModule} from "@ngx-formly/core";
import {FormlyMaterialModule} from "@ngx-formly/material";
import {
  TranslateLoader,
  TranslateModule,
} from "@ngx-translate/core";
import {NgxsReduxDevtoolsPluginModule} from "@ngxs/devtools-plugin";
import {NgxsLoggerPluginModule} from "@ngxs/logger-plugin";
import {NgxsRouterPluginModule} from "@ngxs/router-plugin";
import {NgxsModule} from "@ngxs/store";
import {ErrorsSkipperService} from "@shared/services/errors-skipper.service";
import {StoreDialogService} from "@shared/services/store-dialog.service";
import {StoreRouteService} from "@shared/services/store-route.service";
import {CookieModule} from "ngx-cookie";
import {
  HIGHLIGHT_OPTIONS,
  HighlightModule,
} from "ngx-highlightjs";
import {HighlightOptions} from "ngx-highlightjs/lib/highlight.model";
import {
  TourMatMenuModule,
  TourService,
} from "ngx-ui-tour-md-menu";
import {
  AppConfigService,
  CacheBustingUtil,
  COOKIE_CONSENT_PREFERENCES,
  CustomMatPaginatorIntlService,
  DATA_TABLE_COMPONENT,
  ENVIRONMENT,
  HttpTranslateLoaderExtra,
  ICONS_LIST,
  isFalse,
  isNullOrUndefined,
  isNullOrUndefinedOrWhiteString,
  LABEL_TRANSLATE,
  LanguageInterceptor,
  NotificationService,
  NOTIFIER_SERVICE,
  OAuth2Interceptor,
  OAuthStorage,
  SNACK_BAR,
  SOLIDIFY_CONSTANTS,
  StandardErrorsHandlerService,
  STORE_DIALOG_SERVICE,
  STORE_ROUTE_SERVICE,
  VisualizationState,
} from "solidify-frontend";
import {AppComponent} from "./app.component";
import {MainToolbarDesktopHorizontalPresentational} from "./components/presentationals/main-toolbar/main-toolbar-desktop-horizontal/main-toolbar-desktop-horizontal.presentational";
import {PageNotFoundPresentational} from "./components/presentationals/page-not-found/page-not-found.presentational";

const presentationals = [
  AppComponent,
  MainToolbarPresentational,
  MainToolbarDesktopHorizontalPresentational,
  MainToolbarMobilePresentational,
  BurgerMenuPresentational,
  PageNotFoundPresentational,
  GuidedTourMenuPresentational,
  UserMenuPresentational,
  UserFormPresentational,
];

const containers = [
  FooterContainer,
];

const routables = [];

const dialogs = [
  UserDialog,
  PrivacyPolicyTermsOfUseApprovalDialog,
];

export const appModuleState = [
  AppState,
  AppUserState,
  AppPersonState,
  AppPersonNotificationTypeState,
  AppAuthorizedOrganizationalUnitState,
  AppArchiveAclState,
  AppCartState,
  AppCartArchiveState,
  AppCartOrderState,
  AppCartDipState,
  AppCartDipDataFileState,
  AppTocState,
  AppNotificationInboxState,
  AppSystemPropertyState,
  AppBannerState,
  AppCarouselState,
  VisualizationState,
];

const appInitializerFn = (appConfig: AppConfigService) => () => appConfig.mergeConfig(environment);

export const WINDOW = "windowObject";

export const createDefaultStorage: () => Storage | null = () => environment.tokenInMemoryStorage ? new InMemoryStorage() : (typeof sessionStorage !== "undefined" ? sessionStorage : null);

// required for AOT compilation
export const HttpLoaderFactory: (http: HttpClient) => HttpTranslateLoaderExtra = http => new HttpTranslateLoaderExtra(http, {
  suffix: `.json` + CacheBustingUtil.generateCacheBustingQueryParam(),
}, environment);

@NgModule({
  declarations: [
    ...presentationals,
    ...containers,
    ...routables,
    ...dialogs,
  ],
  imports: [
    // angular
    BrowserModule,
    BrowserAnimationsModule,
    HttpClientModule,
    CookieModule.forRoot(),

    // NgXs
    NgxsModule.forRoot([
      ...appModuleState,
    ], {
      developmentMode: !environment.production, // Allow to enable freeze store in dev env
    }),
    NgxsLoggerPluginModule.forRoot({
      logger: console,
      collapsed: false,
      disabled: isFalse(environment.showDebugInformation) || isNullOrUndefined(environment.showDebugInformation),
    }),
    NgxsReduxDevtoolsPluginModule.forRoot({
      disabled: isFalse(environment.showDebugInformation) || isNullOrUndefined(environment.showDebugInformation),
    }),
    NgxsRouterPluginModule.forRoot(),

    // NgTranslate
    TranslateModule.forRoot({
      loader: {
        provide: TranslateLoader,
        useFactory: HttpLoaderFactory,
        deps: [HttpClient],
      },
    }),

    // Shared
    SharedModule,

    // App
    AppRoutingModule,
    HighlightModule,
    ServiceWorkerModule.register("ngsw-worker.js", {
      enabled: environment.production || environment.forceServiceWorker,
      registrationStrategy: "registerImmediately",
      scope: isNullOrUndefinedOrWhiteString(environment.baseHref) ? SOLIDIFY_CONSTANTS.URL_SEPARATOR : environment.baseHref,
    }),
    ReactiveFormsModule,
    FormlyModule.forRoot(),
    FormlyMaterialModule,
    TourMatMenuModule.forRoot(),
  ],
  providers: [
    TourService,
    {
      provide: ENVIRONMENT,
      useValue: environment,
    },
    {
      provide: LABEL_TRANSLATE,
      useValue: labelTranslateSolidify,
    },
    {
      provide: COOKIE_CONSENT_PREFERENCES,
      useValue: cookieConsentPreferences,
    },
    {
      provide: DATA_TABLE_COMPONENT,
      useValue: dataTableComponentSolidify,
    },
    {
      provide: STORE_ROUTE_SERVICE,
      useClass: StoreRouteService,
    },
    {
      provide: STORE_DIALOG_SERVICE,
      useClass: StoreDialogService,
    },
    {
      provide: ICONS_LIST,
      useValue: icons,
    },
    {
      provide: NOTIFIER_SERVICE,
      useValue: NotificationService,
    },
    {
      provide: APP_INITIALIZER,
      useFactory: appInitializerFn,
      multi: true,
      deps: [AppConfigService],
    },
    {
      provide: HTTP_INTERCEPTORS,
      useExisting: OAuth2Interceptor,
      multi: true,
    },
    {
      provide: HTTP_INTERCEPTORS,
      useClass: LanguageInterceptor,
      multi: true,
    },
    {
      provide: OAuthStorage,
      useFactory: createDefaultStorage,
    },
    {
      provide: MatPaginatorIntl,
      useClass: CustomMatPaginatorIntlService,
    },
    {
      provide: ErrorHandler,
      useClass: StandardErrorsHandlerService,
    },
    {
      provide: SNACK_BAR,
      useClass: MatSnackBar,
    },
    {
      provide: WINDOW,
      useValue: window,
    },
    {
      provide: MAT_MOMENT_DATE_ADAPTER_OPTIONS,
      useValue: {
        useUtc: true,
      },
    },
    {provide: MAT_DATE_LOCALE, useValue: navigator.language},
    {provide: DateAdapter, useClass: MomentDateAdapter, deps: [MAT_DATE_LOCALE]},
    {provide: MAT_DATE_FORMATS, useValue: MAT_MOMENT_DATE_FORMATS},
    ErrorsSkipperService,
    {
      provide: HIGHLIGHT_OPTIONS,
      useValue: {
        coreLibraryLoader: () => import("highlight.js/lib/core"),
        languages: {
          xml: () => import("highlight.js/lib/languages/xml"),
          json: () => import("highlight.js/lib/languages/json"),
        },
        themePath: environment.highlightJsThemeLight,
      } as HighlightOptions,
    },
  ],
  bootstrap: [AppComponent],
})
export class AppModule {
}
