/*-
 * %%----------------------------------------------------------------------------------------------
 * DLCM Technology - DLCM Portal - privacy-policy-terms-of-use-approval.dialog.ts
 * SPDX-License-Identifier: GPL-2.0-or-later
 * %----------------------------------------------------------------------------------------------%
 * Copyright (C) 2017 - 2022 University of Geneva
 * %----------------------------------------------------------------------------------------------%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-2.0.html>.
 * ----------------------------------------------------------------------------------------------%%
 */

import {
  ChangeDetectionStrategy,
  Component,
  Inject,
  OnInit,
} from "@angular/core";
import {
  AbstractControl,
  FormBuilder,
  FormGroup,
  Validators,
} from "@angular/forms";
import {
  MAT_DIALOG_DATA,
  MatDialogRef,
} from "@angular/material/dialog";
import {environment} from "@environments/environment";
import {SharedAbstractDialog} from "@shared/components/dialogs/shared-abstract/shared-abstract.dialog";
import {BaseFormDefinition} from "@shared/models/base-form-definition.model";
import {
  FormValidationHelper,
  PropertyName,
  SolidifyValidator,
} from "solidify-frontend";

@Component({
  selector: "dlcm-privacy-policy-terms-of-use-approval-dialog",
  templateUrl: "./privacy-policy-terms-of-use-approval.dialog.html",
  styleUrls: ["./privacy-policy-terms-of-use-approval.dialog.scss"],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class PrivacyPolicyTermsOfUseApprovalDialog extends SharedAbstractDialog<PrivacyPolicyTermsOfUseApprovalDialogData, boolean> implements OnInit {
  isLoading: boolean = false;
  form: FormGroup;
  formDefinition: FormComponentFormDefinition = new FormComponentFormDefinition();

  readonly privacyPolicyLink: string = environment.privacyPolicyLink;
  readonly termsOfUseLink: string = environment.termsOfUseLink;

  constructor(protected readonly _dialogRef: MatDialogRef<PrivacyPolicyTermsOfUseApprovalDialog>,
              @Inject(MAT_DIALOG_DATA) public readonly data: PrivacyPolicyTermsOfUseApprovalDialogData,
              private readonly _fb: FormBuilder) {
    super(_dialogRef, data);
  }

  ngOnInit(): void {
    super.ngOnInit();
    this.form = this._fb.group({
      [this.formDefinition.acceptPrivacyPolicy]: [false, [Validators.requiredTrue, SolidifyValidator]],
      [this.formDefinition.acceptTermsOfUse]: [false, [Validators.requiredTrue, SolidifyValidator]],
    });
  }

  onSubmit(): void {
    if (this.form.invalid) {
      return;
    }
    this.isLoading = true;
    this.submit(true);
  }

  getFormControl(key: string): AbstractControl {
    return FormValidationHelper.getFormControl(this.form, key);
  }

  get formValidationHelper(): typeof FormValidationHelper {
    return FormValidationHelper;
  }
}

export interface PrivacyPolicyTermsOfUseApprovalDialogData {
}

class FormComponentFormDefinition extends BaseFormDefinition {
  @PropertyName() acceptPrivacyPolicy: string;
  @PropertyName() acceptTermsOfUse: string;
}
