/*-
 * %%----------------------------------------------------------------------------------------------
 * DLCM Technology - DLCM Portal - admin-funding-agencies.state.ts
 * SPDX-License-Identifier: GPL-2.0-or-later
 * %----------------------------------------------------------------------------------------------%
 * Copyright (C) 2017 - 2022 University of Geneva
 * %----------------------------------------------------------------------------------------------%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-2.0.html>.
 * ----------------------------------------------------------------------------------------------%%
 */

import {
  AdminFundingAgenciesAction,
  adminFundingAgenciesActionNameSpace,
} from "@admin/funding-agencies/stores/admin-funding-agencies.action";
import {
  AdminFundingAgenciesOrgUnitAction,
  adminFundingAgenciesOrgUnitActionNameSpace,
} from "@admin/funding-agencies/stores/organizational-unit/admin-organizational-unit-funding-agencies.action";
import {
  AdminFundingAgenciesOrganizationalUnitState,
  AdminFundingAgenciesOrganizationalUnitStateModel,
} from "@admin/funding-agencies/stores/organizational-unit/admin-organizational-unit-funding-agencies.state";
import {HttpClient} from "@angular/common/http";
import {Injectable} from "@angular/core";
import {FundingAgency} from "@models";
import {
  Action,
  Actions,
  Selector,
  State,
  StateContext,
  Store,
} from "@ngxs/store";
import {ApiEnum} from "@shared/enums/api.enum";
import {
  RoutesEnum,
  urlSeparator,
} from "@shared/enums/routes.enum";
import {StateEnum} from "@shared/enums/state.enum";
import {SharedOrgUnitAction} from "@shared/stores/organizational-unit/shared-organizational-unit.action";
import {ResourceLogoStateModel} from "@shared/stores/resource-logo/resource-logo-state.model";
import {
  defaultResourceLogoStateInitValue,
  ResourceLogoState,
  ResourceLogoStateModeEnum,
} from "@shared/stores/resource-logo/resource-logo.state";
import {
  Observable,
  of,
  switchMap,
} from "rxjs";
import {
  map,
  tap,
} from "rxjs/operators";
import {
  ApiService,
  defaultAssociationStateInitValue,
  isNotNullNorUndefined,
  isNullOrUndefined,
  MARK_AS_TRANSLATABLE,
  NotificationService,
  ofSolidifyActionCompleted,
  OverrideDefaultAction,
  StoreUtil,
} from "solidify-frontend";

export interface AdminFundingAgenciesStateModel extends ResourceLogoStateModel<FundingAgency> {
  admin_fundingAgencies_organizationalUnit: AdminFundingAgenciesOrganizationalUnitStateModel;
}

@Injectable()
@State<AdminFundingAgenciesStateModel>({
  name: StateEnum.admin_fundingAgencies,
  defaults: {
    ...defaultResourceLogoStateInitValue(),
    admin_fundingAgencies_organizationalUnit: {...defaultAssociationStateInitValue()},
  },
  children: [
    AdminFundingAgenciesOrganizationalUnitState,
  ],
})
export class AdminFundingAgenciesState extends ResourceLogoState<AdminFundingAgenciesStateModel, FundingAgency> {
  constructor(protected readonly _apiService: ApiService,
              protected readonly _store: Store,
              protected readonly _notificationService: NotificationService,
              protected readonly _actions$: Actions,
              protected readonly _httpClient: HttpClient) {
    super(_apiService, _store, _notificationService, _actions$, {
      nameSpace: adminFundingAgenciesActionNameSpace,
      routeRedirectUrlAfterSuccessCreateAction: (resId: string) => RoutesEnum.adminFundingAgenciesDetail + urlSeparator + resId,
      routeRedirectUrlAfterSuccessUpdateAction: (resId: string) => RoutesEnum.adminFundingAgenciesDetail + urlSeparator + resId,
      routeRedirectUrlAfterSuccessDeleteAction: RoutesEnum.adminFundingAgencies,
      notificationResourceCreateSuccessTextToTranslate: MARK_AS_TRANSLATABLE("admin.funding-agencies.notification.resource.create"),
      notificationResourceDeleteSuccessTextToTranslate: MARK_AS_TRANSLATABLE("admin.funding-agencies.notification.resource.delete"),
      notificationResourceUpdateSuccessTextToTranslate: MARK_AS_TRANSLATABLE("admin.funding-agencies.notification.resource.update"),
    }, _httpClient, ResourceLogoStateModeEnum.logo);
  }

  protected get _urlResource(): string {
    return ApiEnum.adminFundingAgencies;
  }

  protected get _urlLogoResource(): string {
    return this._urlResource;
  }

  @Selector()
  static isLoading(state: AdminFundingAgenciesStateModel): boolean {
    return StoreUtil.isLoadingState(state);
  }

  @Selector()
  static isLoadingWithDependency(state: AdminFundingAgenciesStateModel): boolean {
    return this.isLoading(state)
      || StoreUtil.isLoadingState(state.admin_fundingAgencies_organizationalUnit);
  }

  @Selector()
  static currentTitle(state: AdminFundingAgenciesStateModel): string | undefined {
    if (isNullOrUndefined(state.current)) {
      return undefined;
    }
    return state.current.name;
  }

  @Selector()
  static isReadyToBeDisplayed(state: AdminFundingAgenciesStateModel): boolean {
    return this.isReadyToBeDisplayedInCreateMode
      && !isNullOrUndefined(state.current)
      && !isNullOrUndefined(state.admin_fundingAgencies_organizationalUnit.selected);
  }

  @Selector()
  static isReadyToBeDisplayedInCreateMode(state: AdminFundingAgenciesStateModel): boolean {
    return true;
  }

  @Action(AdminFundingAgenciesAction.LoadResource)
  loadResource(ctx: StateContext<AdminFundingAgenciesStateModel>, action: AdminFundingAgenciesAction.LoadResource): Observable<boolean> {
    ctx.patchState({
      isLoadingCounter: ctx.getState().isLoadingCounter + 1,
    });

    return StoreUtil.dispatchParallelActionAndWaitForSubActionsCompletion(ctx, [
      {
        action: new SharedOrgUnitAction.GetAll(undefined, false, false),
        subActionCompletions: [
          this._actions$.pipe(ofSolidifyActionCompleted(SharedOrgUnitAction.GetAllSuccess)),
          this._actions$.pipe(ofSolidifyActionCompleted(SharedOrgUnitAction.GetAllFail)),
        ],
      },
    ]).pipe(
      map(result => {
        if (result.success) {
          ctx.dispatch(new AdminFundingAgenciesAction.LoadResourceSuccess(action));
        } else {
          ctx.dispatch(new AdminFundingAgenciesAction.LoadResourceFail(action));
        }
        return result.success;
      }),
    );
  }

  @OverrideDefaultAction()
  @Action(AdminFundingAgenciesAction.Create)
  create(ctx: StateContext<AdminFundingAgenciesStateModel>, action: AdminFundingAgenciesAction.Create): Observable<FundingAgency> {
    return super._internalCreate(ctx, action)
      .pipe(
        tap(model => {
          this._updateSubResource(model, action, ctx)
            .subscribe(success => {
              if (success) {
                ctx.dispatch(new AdminFundingAgenciesAction.CreateSuccess(action, model));
              } else {
                ctx.dispatch(new AdminFundingAgenciesAction.CreateFail(action));
              }
            });
        }),
      );
  }

  @OverrideDefaultAction()
  @Action(AdminFundingAgenciesAction.Update)
  update(ctx: StateContext<AdminFundingAgenciesStateModel>, action: AdminFundingAgenciesAction.Update): Observable<FundingAgency> {
    return super._internalUpdate(ctx, action)
      .pipe(
        tap(model => {
          this._updateSubResource(model, action, ctx)
            .subscribe(success => {
              if (success) {
                ctx.dispatch(new AdminFundingAgenciesAction.UpdateSuccess(action, model));
              } else {
                ctx.dispatch(new AdminFundingAgenciesAction.UpdateFail(action));
              }
            });
        }),
      );
  }

  private _updateSubResource(model: FundingAgency, action: AdminFundingAgenciesAction.Create | AdminFundingAgenciesAction.Update, ctx: StateContext<AdminFundingAgenciesStateModel>): Observable<boolean> {
    const fundingAgencyId = model.resId;
    const newOrgUnit = action.modelFormControlEvent.model.organizationalUnits.map(o => o.resId);

    return StoreUtil.dispatchParallelActionAndWaitForSubActionsCompletion(ctx, [{
      action: new AdminFundingAgenciesOrgUnitAction.Update(fundingAgencyId, newOrgUnit),
      subActionCompletions: [
        this._actions$.pipe(ofSolidifyActionCompleted(AdminFundingAgenciesOrgUnitAction.UpdateSuccess)),
        this._actions$.pipe(ofSolidifyActionCompleted(AdminFundingAgenciesOrgUnitAction.UpdateFail)),
      ],
    }]).pipe(
      map(result => result.success),
    );
  }

  @OverrideDefaultAction()
  @Action(AdminFundingAgenciesAction.Delete)
  delete(ctx: StateContext<AdminFundingAgenciesStateModel>, action: AdminFundingAgenciesAction.Delete): Observable<FundingAgency> {
    const oldOrgUnit = ctx.getState().admin_fundingAgencies_organizationalUnit.selected.map(o => o.resId);

    return StoreUtil.dispatchParallelActionAndWaitForSubActionsCompletion(
      ctx,
      [
        {
          action: new adminFundingAgenciesOrgUnitActionNameSpace.DeleteList(action.resId, oldOrgUnit),
          subActionCompletions: [
            this._actions$.pipe(ofSolidifyActionCompleted(adminFundingAgenciesOrgUnitActionNameSpace.DeleteListSuccess)),
            this._actions$.pipe(ofSolidifyActionCompleted(adminFundingAgenciesOrgUnitActionNameSpace.DeleteListFail)),
          ],
        },
      ],
    ).pipe(
      map(result => result.success),
      switchMap(success => {
        if (success) {
          return super.delete(ctx, action);
        } else {
          super.deleteFail(ctx, action as any);
          return of(null);
        }
      }),
    );
  }

  @OverrideDefaultAction()
  @Action(AdminFundingAgenciesAction.GetByIdSuccess)
  getByIdSuccess(ctx: StateContext<AdminFundingAgenciesStateModel>, action: AdminFundingAgenciesAction.GetByIdSuccess): void {
    super.getByIdSuccess(ctx, action);
    if (isNotNullNorUndefined(action.model.logo)) {
      ctx.dispatch(new AdminFundingAgenciesAction.GetPhoto(action.model.resId));
    }
  }
}
