/*-
 * %%----------------------------------------------------------------------------------------------
 * DLCM Technology - DLCM Portal - admin-oai-metadata-prefix-routing.module.ts
 * SPDX-License-Identifier: GPL-2.0-or-later
 * %----------------------------------------------------------------------------------------------%
 * Copyright (C) 2017 - 2022 University of Geneva
 * %----------------------------------------------------------------------------------------------%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-2.0.html>.
 * ----------------------------------------------------------------------------------------------%%
 */

import {AdminOaiMetadataPrefixCreateRoutable} from "@admin/oai-metadata-prefix/components/routables/admin-oai-metadata-prefix-create/admin-oai-metadata-prefix-create.routable";
import {AdminOaiMetadataPrefixDetailEditRoutable} from "@admin/oai-metadata-prefix/components/routables/admin-oai-metadata-prefix-detail-edit/admin-oai-metadata-prefix-detail-edit.routable";
import {AdminOaiMetadataPrefixListRoutable} from "@admin/oai-metadata-prefix/components/routables/admin-oai-metadata-prefix-list/admin-oai-metadata-prefix-list.routable";
import {AdminOaiMetadataPrefixState} from "@admin/oai-metadata-prefix/stores/admin-oai-metadata-prefix.state";
import {NgModule} from "@angular/core";
import {
  RouterModule,
  Routes,
} from "@angular/router";
import {LabelTranslateEnum} from "@shared/enums/label-translate.enum";
import {
  AdminRoutesEnum,
  AppRoutesEnum,
} from "@shared/enums/routes.enum";
import {CanDeactivateGuard} from "solidify-frontend";

const routes: Routes = [
  {
    path: AppRoutesEnum.root,
    component: AdminOaiMetadataPrefixListRoutable,
    data: {},
  },
  {
    path: AdminRoutesEnum.oaiMetadataPrefixCreate,
    component: AdminOaiMetadataPrefixCreateRoutable,
    data: {
      breadcrumb: LabelTranslateEnum.create,
    },
    canDeactivate: [CanDeactivateGuard],
  },
  {
    path: AdminRoutesEnum.oaiMetadataPrefixDetail + AppRoutesEnum.separator + AppRoutesEnum.paramId,
    component: AdminOaiMetadataPrefixDetailEditRoutable,
    data: {
      breadcrumbMemoizedSelector: AdminOaiMetadataPrefixState.currentTitle,
    },
    children: [
      {
        path: AdminRoutesEnum.oaiMetadataPrefixEdit,
        data: {
          breadcrumb: LabelTranslateEnum.edit,
        },
      },
    ],
  },
];

@NgModule({
  imports: [RouterModule.forChild(routes)],
  exports: [RouterModule],
})
export class AdminOaiMetadataPrefixRoutingModule {
}
