/*-
 * %%----------------------------------------------------------------------------------------------
 * DLCM Technology - DLCM Portal - admin-oai-metadata-prefix-form.presentational.ts
 * SPDX-License-Identifier: GPL-2.0-or-later
 * %----------------------------------------------------------------------------------------------%
 * Copyright (C) 2017 - 2022 University of Geneva
 * %----------------------------------------------------------------------------------------------%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-2.0.html>.
 * ----------------------------------------------------------------------------------------------%%
 */

import {
  ChangeDetectionStrategy,
  ChangeDetectorRef,
  Component,
  ElementRef,
  Injector,
} from "@angular/core";
import {
  FormBuilder,
  Validators,
} from "@angular/forms";
import {environment} from "@environments/environment";
import {OaiMetadataPrefix} from "@models";
import {IconNameEnum} from "@shared/enums/icon-name.enum";
import {LabelTranslateEnum} from "@shared/enums/label-translate.enum";
import {BaseFormDefinition} from "@shared/models/base-form-definition.model";
import {
  AbstractFormPresentational,
  PropertyName,
  RegexUtil,
  SolidifyValidator,
} from "solidify-frontend";

@Component({
  selector: "dlcm-admin-oai-metadata-prefix-form",
  templateUrl: "./admin-oai-metadata-prefix-form.presentational.html",
  styleUrls: ["./admin-oai-metadata-prefix-form.presentational.scss"],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class AdminOaiMetadataPrefixFormPresentational extends AbstractFormPresentational<OaiMetadataPrefix> {
  formDefinition: FormComponentFormDefinition = new FormComponentFormDefinition();

  get labelTranslateEnum(): typeof LabelTranslateEnum {
    return LabelTranslateEnum;
  }

  get iconNameEnum(): typeof IconNameEnum {
    return IconNameEnum;
  }

  readonly TIME_BEFORE_DISPLAY_TOOLTIP: number = environment.timeBeforeDisplayTooltip;

  constructor(protected readonly _changeDetectorRef: ChangeDetectorRef,
              protected readonly _elementRef: ElementRef,
              protected readonly _injector: Injector,
              private readonly _fb: FormBuilder) {
    super(_changeDetectorRef, _elementRef, _injector);
  }

  protected _initNewForm(): void {
    this.form = this._fb.group({
      [this.formDefinition.prefix]: ["", [Validators.required, SolidifyValidator]],
      [this.formDefinition.name]: ["", [Validators.required, SolidifyValidator]],
      [this.formDefinition.description]: ["", [Validators.required, SolidifyValidator]],
      [this.formDefinition.schemaNamespace]: ["", [Validators.required, SolidifyValidator]],
      [this.formDefinition.schemaUrl]: ["", [Validators.required, SolidifyValidator, Validators.pattern(RegexUtil.url)]],
      [this.formDefinition.enabled]: [false, [SolidifyValidator]],
      [this.formDefinition.reference]: [false, [SolidifyValidator]],
      [this.formDefinition.metadataSchema]: ["", [SolidifyValidator]],
      [this.formDefinition.metadataXmlTransformation]: ["", [SolidifyValidator]],
    });
  }

  protected _bindFormTo(oaiMetadataPrefix: OaiMetadataPrefix): void {
    this.form = this._fb.group({
      [this.formDefinition.prefix]: [oaiMetadataPrefix.prefix, [Validators.required, SolidifyValidator]],
      [this.formDefinition.name]: [oaiMetadataPrefix.name, [Validators.required, SolidifyValidator]],
      [this.formDefinition.description]: [oaiMetadataPrefix.description, [Validators.required, SolidifyValidator]],
      [this.formDefinition.schemaNamespace]: [oaiMetadataPrefix.schemaNamespace, [Validators.required, SolidifyValidator]],
      [this.formDefinition.schemaUrl]: [oaiMetadataPrefix.schemaUrl, [Validators.required, SolidifyValidator, Validators.pattern(RegexUtil.url)]],
      [this.formDefinition.enabled]: [oaiMetadataPrefix.enabled, [SolidifyValidator]],
      [this.formDefinition.reference]: [oaiMetadataPrefix.reference, [SolidifyValidator]],
      [this.formDefinition.metadataSchema]: [oaiMetadataPrefix.metadataSchema, [SolidifyValidator]],
      [this.formDefinition.metadataXmlTransformation]: [oaiMetadataPrefix.metadataXmlTransformation, [SolidifyValidator]],
    });
  }

  protected _treatmentBeforeSubmit(OaiMetadataPrefixes: OaiMetadataPrefix): OaiMetadataPrefix {
    return OaiMetadataPrefixes;
  }
}

class FormComponentFormDefinition extends BaseFormDefinition {
  @PropertyName() prefix: string;
  @PropertyName() name: string;
  @PropertyName() description: string;
  @PropertyName() schemaNamespace: string;
  @PropertyName() schemaUrl: string;
  @PropertyName() enabled: string;
  @PropertyName() reference: string;
  @PropertyName() metadataSchema: string;
  @PropertyName() metadataXmlTransformation: string;
}
