/*-
 * %%----------------------------------------------------------------------------------------------
 * DLCM Technology - DLCM Portal - admin-oai-metadata-prefix.state.ts
 * SPDX-License-Identifier: GPL-2.0-or-later
 * %----------------------------------------------------------------------------------------------%
 * Copyright (C) 2017 - 2022 University of Geneva
 * %----------------------------------------------------------------------------------------------%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-2.0.html>.
 * ----------------------------------------------------------------------------------------------%%
 */

import {
  AdminOaiMetadataPrefixAction,
  adminOaiMetadataPrefixActionNameSpace,
} from "@admin/oai-metadata-prefix/stores/admin-oai-metadata-prefix.action";
import {Injectable} from "@angular/core";
import {OaiMetadataPrefix} from "@models";
import {
  Action,
  Actions,
  Selector,
  State,
  StateContext,
  Store,
} from "@ngxs/store";
import {ApiEnum} from "@shared/enums/api.enum";
import {
  RoutesEnum,
  urlSeparator,
} from "@shared/enums/routes.enum";
import {StateEnum} from "@shared/enums/state.enum";
import {SharedOrgUnitAction} from "@shared/stores/organizational-unit/shared-organizational-unit.action";
import {Observable} from "rxjs";
import {map} from "rxjs/operators";
import {
  ApiService,
  defaultResourceStateInitValue,
  isNullOrUndefined,
  MARK_AS_TRANSLATABLE,
  NotificationService,
  ofSolidifyActionCompleted,
  ResourceState,
  ResourceStateModel,
  StoreUtil,
} from "solidify-frontend";

export interface AdminOaiMetadataPrefixStateModel extends ResourceStateModel<OaiMetadataPrefix> {
}

@Injectable()
@State<AdminOaiMetadataPrefixStateModel>({
  name: StateEnum.admin_oaiMetadataPrefix,
  defaults: {
    ...defaultResourceStateInitValue(),
  },
})
export class AdminOaiMetadataPrefixState extends ResourceState<AdminOaiMetadataPrefixStateModel, OaiMetadataPrefix> {
  constructor(protected readonly _apiService: ApiService,
              protected readonly _store: Store,
              protected readonly _notificationService: NotificationService,
              protected readonly _actions$: Actions) {
    super(_apiService, _store, _notificationService, _actions$, {
      nameSpace: adminOaiMetadataPrefixActionNameSpace,
      routeRedirectUrlAfterSuccessCreateAction: (resId: string) => RoutesEnum.adminOaiMetadataPrefixDetail + urlSeparator + resId,
      routeRedirectUrlAfterSuccessUpdateAction: (resId: string) => RoutesEnum.adminOaiMetadataPrefixDetail + urlSeparator + resId,
      routeRedirectUrlAfterSuccessDeleteAction: RoutesEnum.adminOaiMetadataPrefix,
      notificationResourceCreateSuccessTextToTranslate: MARK_AS_TRANSLATABLE("admin.oai-metadata-prefix.notification.resource.create"),
      notificationResourceDeleteSuccessTextToTranslate: MARK_AS_TRANSLATABLE("admin.oai-metadata-prefix.notification.resource.delete"),
      notificationResourceUpdateSuccessTextToTranslate: MARK_AS_TRANSLATABLE("admin.oai-metadata-prefix.notification.resource.update"),
    });
  }

  protected get _urlResource(): string {
    return ApiEnum.oaiInfoOaiMetadataPrefixes;
  }

  @Selector()
  static isLoading(state: AdminOaiMetadataPrefixStateModel): boolean {
    return StoreUtil.isLoadingState(state);
  }

  @Selector()
  static isLoadingWithDependency(state: AdminOaiMetadataPrefixStateModel): boolean {
    return this.isLoading(state);
  }

  @Selector()
  static isReadyToBeDisplayed(state: AdminOaiMetadataPrefixStateModel): boolean {
    return this.isReadyToBeDisplayedInCreateMode
      && !isNullOrUndefined(state.current);
  }

  @Selector()
  static isReadyToBeDisplayedInCreateMode(state: AdminOaiMetadataPrefixStateModel): boolean {
    return true;
  }

  @Selector()
  static currentTitle(state: AdminOaiMetadataPrefixStateModel): string | undefined {
    if (isNullOrUndefined(state.current)) {
      return undefined;
    }
    return state.current.name;
  }

  @Action(AdminOaiMetadataPrefixAction.LoadResource)
  loadResource(ctx: StateContext<AdminOaiMetadataPrefixStateModel>, action: AdminOaiMetadataPrefixAction.LoadResource): Observable<boolean> {
    ctx.patchState({
      isLoadingCounter: ctx.getState().isLoadingCounter + 1,
    });

    return StoreUtil.dispatchParallelActionAndWaitForSubActionsCompletion(ctx, [
      {
        action: new SharedOrgUnitAction.GetAll(undefined, false, false),
        subActionCompletions: [
          this._actions$.pipe(ofSolidifyActionCompleted(SharedOrgUnitAction.GetAllSuccess)),
          this._actions$.pipe(ofSolidifyActionCompleted(SharedOrgUnitAction.GetAllFail)),
        ],
      },
    ]).pipe(
      map(result => {
        if (result.success) {
          ctx.dispatch(new AdminOaiMetadataPrefixAction.LoadResourceSuccess(action));
        } else {
          ctx.dispatch(new AdminOaiMetadataPrefixAction.LoadResourceFail(action));
        }
        return result.success;
      }),
    );
  }
}
