/*-
 * %%----------------------------------------------------------------------------------------------
 * DLCM Technology - DLCM Portal - admin-oai-set-routing.module.ts
 * SPDX-License-Identifier: GPL-2.0-or-later
 * %----------------------------------------------------------------------------------------------%
 * Copyright (C) 2017 - 2022 University of Geneva
 * %----------------------------------------------------------------------------------------------%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-2.0.html>.
 * ----------------------------------------------------------------------------------------------%%
 */

import {AdminOaiSetBulkCreateRoutable} from "@admin/oai-set/components/routables/admin-oai-set-bulk-create/admin-oai-set-bulk-create.routable";
import {AdminOaiSetCreateRoutable} from "@admin/oai-set/components/routables/admin-oai-set-create/admin-oai-set-create.routable";
import {AdminOaiSetDetailEditRoutable} from "@admin/oai-set/components/routables/admin-oai-set-detail-edit/admin-oai-set-detail-edit.routable";
import {AdminOaiSetListRoutable} from "@admin/oai-set/components/routables/admin-oai-set-list/admin-oai-set-list.routable";
import {AdminOaiSetState} from "@admin/oai-set/stores/admin-oai-set.state";
import {NgModule} from "@angular/core";
import {
  RouterModule,
  Routes,
} from "@angular/router";
import {LabelTranslateEnum} from "@shared/enums/label-translate.enum";
import {
  AdminRoutesEnum,
  AppRoutesEnum,
} from "@shared/enums/routes.enum";
import {CanDeactivateGuard} from "solidify-frontend";

const routes: Routes = [
  {
    path: AppRoutesEnum.root,
    component: AdminOaiSetListRoutable,
    data: {},
  },
  {
    path: AdminRoutesEnum.oaiSetCreate,
    component: AdminOaiSetCreateRoutable,
    data: {
      breadcrumb: LabelTranslateEnum.create,
    },
    canDeactivate: [CanDeactivateGuard],
  },
  {
    path: AdminRoutesEnum.oaiSetDetail + AppRoutesEnum.separator + AppRoutesEnum.paramId,
    component: AdminOaiSetDetailEditRoutable,
    data: {
      breadcrumbMemoizedSelector: AdminOaiSetState.currentTitle,
    },
    children: [
      {
        path: AdminRoutesEnum.oaiSetEdit,
        data: {
          breadcrumb: LabelTranslateEnum.edit,
        },
      },
    ],
  },
  {
    path: AdminRoutesEnum.oaiSetBulkCreate,
    component: AdminOaiSetBulkCreateRoutable,
    data: {
      breadcrumb: LabelTranslateEnum.create,
    },
    canDeactivate: [CanDeactivateGuard],
  },
];

@NgModule({
  imports: [RouterModule.forChild(routes)],
  exports: [RouterModule],
})
export class AdminOaiSetRoutingModule {
}
