/*-
 * %%----------------------------------------------------------------------------------------------
 * DLCM Technology - DLCM Portal - admin-user.action.ts
 * SPDX-License-Identifier: GPL-2.0-or-later
 * %----------------------------------------------------------------------------------------------%
 * Copyright (C) 2017 - 2022 University of Geneva
 * %----------------------------------------------------------------------------------------------%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-2.0.html>.
 * ----------------------------------------------------------------------------------------------%%
 */

import {User} from "@models";
import {StateEnum} from "@shared/enums/state.enum";
import {ResourceLogoNameSpace} from "@shared/stores/resource-logo/resource-logo-namespace.model";
import {ResourceLogoAction} from "@shared/stores/resource-logo/resource-logo.action";
import {
  BaseAction,
  BaseSubActionFail,
  BaseSubActionSuccess,
  ResourceAction,
  Result,
  TypeDefaultAction,
} from "solidify-frontend";

const state = StateEnum.admin_user;

export namespace AdminUserAction {
  @TypeDefaultAction(state)
  export class LoadResource extends ResourceAction.LoadResource {
  }

  @TypeDefaultAction(state)
  export class LoadResourceSuccess extends ResourceAction.LoadResourceSuccess {
  }

  @TypeDefaultAction(state)
  export class LoadResourceFail extends ResourceAction.LoadResourceFail {
  }

  @TypeDefaultAction(state)
  export class ChangeQueryParameters extends ResourceAction.ChangeQueryParameters {
  }

  @TypeDefaultAction(state)
  export class GetAll extends ResourceAction.GetAll {
  }

  @TypeDefaultAction(state)
  export class GetAllSuccess extends ResourceAction.GetAllSuccess<User> {
  }

  @TypeDefaultAction(state)
  export class GetAllFail extends ResourceAction.GetAllFail<User> {
  }

  @TypeDefaultAction(state)
  export class GetByListId extends ResourceAction.GetByListId {
  }

  @TypeDefaultAction(state)
  export class GetByListIdSuccess extends ResourceAction.GetByListIdSuccess {
  }

  @TypeDefaultAction(state)
  export class GetByListIdFail extends ResourceAction.GetByListIdFail {
  }

  @TypeDefaultAction(state)
  export class GetById extends ResourceAction.GetById {
  }

  @TypeDefaultAction(state)
  export class GetByIdSuccess extends ResourceAction.GetByIdSuccess<User> {
  }

  @TypeDefaultAction(state)
  export class GetByIdFail extends ResourceAction.GetByIdFail<User> {
  }

  @TypeDefaultAction(state)
  export class Create extends ResourceAction.Create<User> {
  }

  @TypeDefaultAction(state)
  export class CreateSuccess extends ResourceAction.CreateSuccess<User> {
  }

  @TypeDefaultAction(state)
  export class CreateFail extends ResourceAction.CreateFail<User> {
  }

  @TypeDefaultAction(state)
  export class Update extends ResourceAction.Update<User> {
  }

  @TypeDefaultAction(state)
  export class UpdateSuccess extends ResourceAction.UpdateSuccess<User> {
  }

  @TypeDefaultAction(state)
  export class UpdateFail extends ResourceAction.UpdateFail<User> {
  }

  @TypeDefaultAction(state)
  export class Delete extends ResourceAction.Delete {
  }

  @TypeDefaultAction(state)
  export class DeleteSuccess extends ResourceAction.DeleteSuccess {
  }

  @TypeDefaultAction(state)
  export class DeleteFail extends ResourceAction.DeleteFail {
  }

  @TypeDefaultAction(state)
  export class DeleteList extends ResourceAction.DeleteList {
  }

  @TypeDefaultAction(state)
  export class DeleteListSuccess extends ResourceAction.DeleteListSuccess {
  }

  @TypeDefaultAction(state)
  export class DeleteListFail extends ResourceAction.DeleteListFail {
  }

  @TypeDefaultAction(state)
  export class AddInList extends ResourceAction.AddInList<User> {
  }

  @TypeDefaultAction(state)
  export class AddInListById extends ResourceAction.AddInListById {
  }

  @TypeDefaultAction(state)
  export class AddInListByIdSuccess extends ResourceAction.AddInListByIdSuccess<User> {
  }

  @TypeDefaultAction(state)
  export class AddInListByIdFail extends ResourceAction.AddInListByIdFail<User> {
  }

  @TypeDefaultAction(state)
  export class RemoveInListById extends ResourceAction.RemoveInListById {
  }

  @TypeDefaultAction(state)
  export class RemoveInListByListId extends ResourceAction.RemoveInListByListId {
  }

  @TypeDefaultAction(state)
  export class LoadNextChunkList extends ResourceAction.LoadNextChunkList {
  }

  @TypeDefaultAction(state)
  export class LoadNextChunkListSuccess extends ResourceAction.LoadNextChunkListSuccess<User> {
  }

  @TypeDefaultAction(state)
  export class LoadNextChunkListFail extends ResourceAction.LoadNextChunkListFail {
  }

  @TypeDefaultAction(state)
  export class Clean extends ResourceAction.Clean {
  }

  @TypeDefaultAction(state)
  export class GetPhoto extends ResourceLogoAction.GetPhoto {
  }

  @TypeDefaultAction(state)
  export class GetPhotoSuccess extends ResourceLogoAction.GetPhotoSuccess {
  }

  @TypeDefaultAction(state)
  export class GetPhotoFail extends ResourceLogoAction.GetPhotoFail {
  }

  @TypeDefaultAction(state)
  export class GetPhotoByResId extends ResourceLogoAction.GetPhotoByResId {
  }

  @TypeDefaultAction(state)
  export class GetPhotoByResIdSuccess extends ResourceLogoAction.GetPhotoByResIdSuccess {
  }

  @TypeDefaultAction(state)
  export class GetPhotoByResIdFail extends ResourceLogoAction.GetPhotoByResIdFail {
  }

  @TypeDefaultAction(state)
  export class UploadPhoto extends ResourceLogoAction.UploadPhoto {
  }

  @TypeDefaultAction(state)
  export class UploadPhotoSuccess extends ResourceLogoAction.UploadPhotoSuccess {
  }

  @TypeDefaultAction(state)
  export class UploadPhotoFail extends ResourceLogoAction.UploadPhotoFail {
  }

  @TypeDefaultAction(state)
  export class DeletePhoto extends ResourceLogoAction.DeletePhoto {
  }

  @TypeDefaultAction(state)
  export class DeletePhotoSuccess extends ResourceLogoAction.DeletePhotoSuccess {
  }

  @TypeDefaultAction(state)
  export class DeletePhotoFail extends ResourceLogoAction.DeletePhotoFail {
  }

  export class Refresh extends BaseAction {
    static readonly type: string = `[${state}] Refresh`;
  }

  export class RefreshSuccess extends BaseSubActionSuccess<Refresh> {
    static readonly type: string = `[${state}] Refresh Success`;

    constructor(public parentAction: Refresh, public result: Result) {
      super(parentAction);
    }
  }

  export class RefreshFail extends BaseSubActionFail<Refresh> {
    static readonly type: string = `[${state}] Refresh Fail`;
  }

  export class Synchronize extends BaseAction {
    static readonly type: string = `[${state}] Synchronize`;
  }

  export class SynchronizeSuccess extends BaseSubActionSuccess<Synchronize> {
    static readonly type: string = `[${state}] Synchronize Success`;

    constructor(public parentAction: Synchronize, public result: Result) {
      super(parentAction);
    }
  }

  export class SynchronizeFail extends BaseSubActionFail<Synchronize> {
    static readonly type: string = `[${state}] Synchronize Fail`;
  }
}

export const adminUserActionNameSpace: ResourceLogoNameSpace = AdminUserAction;
