/*-
 * %%----------------------------------------------------------------------------------------------
 * DLCM Technology - DLCM Portal - abstract-deposit-file-upload.dialog.ts
 * SPDX-License-Identifier: GPL-2.0-or-later
 * %----------------------------------------------------------------------------------------------%
 * Copyright (C) 2017 - 2022 University of Geneva
 * %----------------------------------------------------------------------------------------------%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-2.0.html>.
 * ----------------------------------------------------------------------------------------------%%
 */

import {
  Directive,
  OnInit,
} from "@angular/core";
import {
  AbstractControl,
  FormBuilder,
  FormGroup,
  Validators,
} from "@angular/forms";
import {MatDialogRef} from "@angular/material/dialog";
import {BaseFormDefinition} from "@app/shared/models/base-form-definition.model";
import {depositDataFileMetadataTypeActionNameSpace} from "@deposit/stores/data-file/metadata-type/deposit-data-file-metadata-type.action";
import {DepositDataFileMetadataTypeState} from "@deposit/stores/data-file/metadata-type/deposit-data-file-metadata-type.state";
import {Enums} from "@enums";
import {MetadataType} from "@models";
import {SharedAbstractDialog} from "@shared/components/dialogs/shared-abstract/shared-abstract.dialog";
import {tap} from "rxjs/operators";
import {
  FormValidationHelper,
  PropertyName,
  ResourceNameSpace,
} from "solidify-frontend";

@Directive()
export abstract class AbstractDepositFileUploadDialog<TData, UResult> extends SharedAbstractDialog<TData, UResult> implements OnInit {
  form: FormGroup;
  formDefinition: AbstractDepositFileUploadFormComponentFormDefinition = new AbstractDepositFileUploadFormComponentFormDefinition();

  get dataTypeEnum(): typeof Enums.DataFile.DataTypeEnum {
    return Enums.DataFile.DataTypeEnum;
  }

  getFormControl(key: string): AbstractControl {
    return FormValidationHelper.getFormControl(this.form, key);
  }

  metadataTypeLabelCallback: (value: MetadataType) => string = value => value.fullName;

  readonly REGEX_INVALID: RegExp = new RegExp("[~!@#$%^&*`;?,\\\\]");
  readonly files: string = "files";

  depositDataFileMetadataTypeActionNameSpace: ResourceNameSpace = depositDataFileMetadataTypeActionNameSpace;
  depositDataFileMetadataTypeState: typeof DepositDataFileMetadataTypeState = DepositDataFileMetadataTypeState;

  constructor(protected readonly _dialogRef: MatDialogRef<AbstractDepositFileUploadDialog<TData, UResult>>,
              protected readonly _fb: FormBuilder,
              protected readonly _data: TData,
  ) {
    super(_dialogRef, _data);
  }

  ngOnInit(): void {
    super.ngOnInit();
    this.form = this._fb.group({
      [this.formDefinition.dataCategory]: [Enums.DataFile.DataCategoryEnum.Primary, [Validators.required]],
      [this.formDefinition.dataType]: [Enums.DataFile.DataTypeEnum.Reference, [Validators.required]],
      [this.formDefinition.metadataType]: [""],
    });

    this.subscribe(this.form.get(this.formDefinition.dataType).valueChanges.pipe(
      tap(value => {
        const metadataFormControl = this.form.get(this.formDefinition.metadataType);
        if (value === Enums.DataFile.DataTypeEnum.CustomMetadata) {
          metadataFormControl.setValidators([Validators.required]);
        } else {
          metadataFormControl.setValidators([]);
        }
        metadataFormControl.updateValueAndValidity();
      }),
    ));
  }

  get formValidationHelper(): typeof FormValidationHelper {
    return FormValidationHelper;
  }

  abstract onFileChange(event: Event & any): void;

  getDate(lastModified: number): Date {
    return new Date(lastModified);
  }

  abstract onSubmit(): void;

  getDataCategory(): Enums.DataFile.DataCategoryEnum {
    return this.form.get(this.formDefinition.dataCategory).value;
  }

  abstract delete(file: File, index?: number): void;
}

export class AbstractDepositFileUploadFormComponentFormDefinition extends BaseFormDefinition {
  @PropertyName() dataCategory: string;
  @PropertyName() dataType: string;
  @PropertyName() metadataType: string;
}
