/*-
 * %%----------------------------------------------------------------------------------------------
 * DLCM Technology - DLCM Portal - deposit-authorized-organizational-unit.state.ts
 * SPDX-License-Identifier: GPL-2.0-or-later
 * %----------------------------------------------------------------------------------------------%
 * Copyright (C) 2017 - 2022 University of Geneva
 * %----------------------------------------------------------------------------------------------%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-2.0.html>.
 * ----------------------------------------------------------------------------------------------%%
 */

import {Injectable} from "@angular/core";
import {ApiEnum} from "@app/shared/enums/api.enum";
import {AppAuthorizedOrganizationalUnitAction} from "@app/stores/authorized-organizational-unit/app-authorized-organizational-unit.action";
import {
  DepositAuthorizedOrganizationalUnitAction,
  depositAuthorizedOrganizationalUnitNameSpace,
} from "@deposit/stores/authorized-organizational-unit/deposit-authorized-organizational-unit.action";
import {environment} from "@environments/environment";
import {OrganizationalUnit} from "@models";
import {
  Action,
  Actions,
  State,
  StateContext,
  Store,
} from "@ngxs/store";
import {StateEnum} from "@shared/enums/state.enum";
import {
  ApiService,
  defaultResourceStateInitValue,
  MappingObjectUtil,
  NotificationService,
  OrderEnum,
  OverrideDefaultAction,
  QueryParameters,
  ResourceState,
  ResourceStateModel,
} from "solidify-frontend";

export interface DepositAuthorizedOrganizationalUnitStateModel extends ResourceStateModel<OrganizationalUnit> {
}

export const defaultDepositAuthorizedOrgUnitValue: () => DepositAuthorizedOrganizationalUnitStateModel = () =>
  ({
    ...defaultResourceStateInitValue(),
    queryParameters: getQueryParameter(),
  });

// WARNING : IN SOME CASE WE NEED TO FILTER TO GET ONLY OPENED ORG UNIT
const getQueryParameter: () => QueryParameters = () => {
  const queryParameters = new QueryParameters(environment.defaultEnumValuePageSizeLazyLoad, {
    field: "name" as keyof OrganizationalUnit,
    order: OrderEnum.ascending,
  });
  MappingObjectUtil.set(queryParameters.search.searchItems, "openOnly", "true");
  return queryParameters;
};

@Injectable()
@State<DepositAuthorizedOrganizationalUnitStateModel>({
  name: StateEnum.deposit_authorizedOrganizationalUnit,
  defaults: {
    ...defaultDepositAuthorizedOrgUnitValue(),
  },
})
export class DepositAuthorizedOrganizationalUnitState extends ResourceState<DepositAuthorizedOrganizationalUnitStateModel, OrganizationalUnit> {

  constructor(protected readonly _apiService: ApiService,
              protected readonly _store: Store,
              protected readonly _notificationService: NotificationService,
              protected readonly _actions$: Actions) {
    super(_apiService, _store, _notificationService, _actions$, {
      nameSpace: depositAuthorizedOrganizationalUnitNameSpace,
    });
  }

  protected get _urlResource(): string {
    return ApiEnum.adminAuthorizedOrganizationalUnits;
  }

  @OverrideDefaultAction()
  @Action(DepositAuthorizedOrganizationalUnitAction.GetByIdSuccess)
  getByIdSuccess(ctx: StateContext<DepositAuthorizedOrganizationalUnitStateModel>, action: DepositAuthorizedOrganizationalUnitAction.GetByIdSuccess): void {
    super.getByIdSuccess(ctx, action);
    ctx.dispatch(new AppAuthorizedOrganizationalUnitAction.AddOrUpdateInList(action.model));
  }
}
