/*-
 * %%----------------------------------------------------------------------------------------------
 * DLCM Technology - DLCM Portal - home-carousel.presentational.ts
 * SPDX-License-Identifier: GPL-2.0-or-later
 * %----------------------------------------------------------------------------------------------%
 * Copyright (C) 2017 - 2022 University of Geneva
 * %----------------------------------------------------------------------------------------------%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-2.0.html>.
 * ----------------------------------------------------------------------------------------------%%
 */

import {
  ChangeDetectionStrategy,
  ChangeDetectorRef,
  Component,
  HostListener,
  Input,
  OnInit,
} from "@angular/core";
import {environment} from "@environments/environment";
import {SharedAbstractPresentational} from "@shared/components/presentationals/shared-abstract/shared-abstract.presentational";
import {PollingHelper} from "solidify-frontend";

@Component({
  selector: "dlcm-home-carousel",
  templateUrl: "./home-carousel.presentational.html",
  styleUrls: ["./home-carousel.presentational.scss"],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class HomeCarouselPresentational extends SharedAbstractPresentational implements OnInit {
  activeTile: number = 0;
  skipNextChangeDueToHover: boolean = false;
  skipNextChangeDueToManualChangeOfTiles: boolean = false;

  private _listTiles: Node[];
  @Input()
  set listTiles(value: Node[]) {
    this._listTiles = value;
    this.activeTile = 0;
  }

  get listTiles(): Node[] {
    return this._listTiles;
  }

  @HostListener("mouseenter")
  onMouseEnter(): void {
    this.skipNextChangeDueToHover = true;
  }

  @HostListener("mouseleave")
  onMouseLeave(): void {
    this.skipNextChangeDueToHover = false;
  }

  constructor(private readonly _changeDetector: ChangeDetectorRef) {
    super();
  }

  ngOnInit(): void {
    super.ngOnInit();

    this.subscribe(PollingHelper.startPollingObs({
      initialIntervalRefreshInSecond: environment.frequencyChangeCarouselTileInSecond,
      filter: () => {
        if (this.skipNextChangeDueToManualChangeOfTiles) {
          this.skipNextChangeDueToManualChangeOfTiles = false;
          return false;
        }
        if (this.skipNextChangeDueToHover) {
          return false;
        }
        return true;
      },
      actionToDo: () => this._changeActiveTile(),
    }));
  }

  setActive(index: number): void {
    this.activeTile = index;
    this.skipNextChangeDueToManualChangeOfTiles = true;
  }

  private _changeActiveTile(): void {
    this.activeTile++;
    if (this.activeTile >= this.listTiles?.length) {
      this.activeTile = 0;
    }
    this._changeDetector.detectChanges();
  }
}
