/*-
 * %%----------------------------------------------------------------------------------------------
 * DLCM Technology - DLCM Portal - home-archive-file-detail.routable.ts
 * SPDX-License-Identifier: GPL-2.0-or-later
 * %----------------------------------------------------------------------------------------------%
 * Copyright (C) 2017 - 2022 University of Geneva
 * %----------------------------------------------------------------------------------------------%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-2.0.html>.
 * ----------------------------------------------------------------------------------------------%%
 */

import {
  ChangeDetectionStrategy,
  ChangeDetectorRef,
  Component,
  OnInit,
} from "@angular/core";
import {MatDialog} from "@angular/material/dialog";
import {ActivatedRoute} from "@angular/router";
import {ArchiveDataFile} from "@home/models/archive-data-file.model";
import {HomeArchiveDataFileAction} from "@home/stores/archive/data-file/home-archive-data-file.action";
import {HomeArchiveDataFileState} from "@home/stores/archive/data-file/home-archive-data-file.state";
import {
  Actions,
  Store,
} from "@ngxs/store";
import {
  SharedFileAndAipDetailDialogModeEnum,
  SharedFileAndAipInformationDialogData,
} from "@shared/components/containers/shared-file-and-aip-information/shared-file-and-aip-information.container";
import {SharedAbstractRoutable} from "@shared/components/routables/shared-abstract/shared-abstract.routable";
import {AppRoutesEnum} from "@shared/enums/routes.enum";
import {isNotNullOrUndefined} from "codelyzer/util/isNotNullOrUndefined";
import {Observable} from "rxjs";
import {
  filter,
  tap,
} from "rxjs/operators";
import {MemoizedUtil} from "solidify-frontend";

@Component({
  selector: "dlcm-home-archive-file-detail-routable",
  templateUrl: "./home-archive-file-detail.routable.html",
  styleUrls: ["../../../../../shared/components/routables/shared-abstract-file-aip-detail/shared-abstract-file-aip-detail.routable.scss"],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class HomeArchiveFileDetailRoutable extends SharedAbstractRoutable implements OnInit {
  data: SharedFileAndAipInformationDialogData<ArchiveDataFile>;
  archiveDataFile: Observable<ArchiveDataFile> = MemoizedUtil.select(this._store, HomeArchiveDataFileState, state => state.current);
  mode: SharedFileAndAipDetailDialogModeEnum = SharedFileAndAipDetailDialogModeEnum.file;

  protected _parentId: string | undefined;
  protected _dataFileId: string | undefined;

  constructor(protected readonly _store: Store,
              protected readonly _route: ActivatedRoute,
              protected readonly _actions$: Actions,
              protected readonly _dialog: MatDialog,
              protected readonly _changeDetector: ChangeDetectorRef) {
    super();
  }

  ngOnInit(): void {
    super.ngOnInit();
    this._retrieveResIdFromUrl();
    this._store.dispatch(new HomeArchiveDataFileAction.GetById(this._parentId, this._dataFileId));
    this.subscribe(this._observableCreateData());
  }

  protected _retrieveResIdFromUrl(): void {
    this._dataFileId = this._route.snapshot.paramMap.get(AppRoutesEnum.paramIdDataFileWithoutPrefixParam);
    this._parentId = this._route.parent.parent.snapshot.paramMap.get(AppRoutesEnum.paramIdWithoutPrefixParam);
  }

  protected _observableCreateData(): Observable<ArchiveDataFile> {
    return this.archiveDataFile.pipe(
      filter(resource => isNotNullOrUndefined(resource) && resource.resId === this._dataFileId),
      tap(resource => {
        this.data = {
          mode: this.mode,
          dataFile: resource,
          storage: undefined,
          resId: resource.resId,
          parentId: this._parentId,
          buttons: [],
        } as SharedFileAndAipInformationDialogData<ArchiveDataFile>;
        this._changeDetector.detectChanges();
      }),
    );
  }

}


