/*-
 * %%----------------------------------------------------------------------------------------------
 * DLCM Technology - DLCM Portal - preservation-space-contributor-deposit.state.ts
 * SPDX-License-Identifier: GPL-2.0-or-later
 * %----------------------------------------------------------------------------------------------%
 * Copyright (C) 2017 - 2022 University of Geneva
 * %----------------------------------------------------------------------------------------------%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-2.0.html>.
 * ----------------------------------------------------------------------------------------------%%
 */

import {Injectable} from "@angular/core";
import {Deposit} from "@models";
import {
  Actions,
  Selector,
  State,
  Store,
} from "@ngxs/store";
import {preservationSpaceContributorDepositActionNameSpace} from "@preservation-space/contributor/stores/contributor-deposit/preservation-space-contributor-deposit.action";
import {ApiResourceNameEnum} from "@shared/enums/api-resource-name.enum";
import {ApiEnum} from "@shared/enums/api.enum";
import {StateEnum} from "@shared/enums/state.enum";
import {
  ApiService,
  CompositionState,
  CompositionStateModel,
  defaultCompositionStateInitValue,
  isNullOrUndefined,
  NotificationService,
  StoreUtil,
} from "solidify-frontend";

export const defaultPreservationSpaceContributorDepositStateModel: () => PreservationSpaceContributorDepositStateModel = () =>
  ({
    ...defaultCompositionStateInitValue(),
  });

export interface PreservationSpaceContributorDepositStateModel extends CompositionStateModel<Deposit> {
}

@Injectable()
@State<PreservationSpaceContributorDepositStateModel>({
  name: StateEnum.preservationSpace_contributor_deposit,
  defaults: {
    ...defaultPreservationSpaceContributorDepositStateModel(),
  },
})
export class PreservationSpaceContributorDepositState extends CompositionState<PreservationSpaceContributorDepositStateModel, Deposit> {
  constructor(protected readonly _apiService: ApiService,
              protected readonly _store: Store,
              protected readonly _notificationService: NotificationService,
              protected readonly _actions$: Actions) {
    super(_apiService, _store, _notificationService, _actions$, {
      nameSpace: preservationSpaceContributorDepositActionNameSpace,
      resourceName: ApiResourceNameEnum.DEPOSIT,
    });
  }

  protected get _urlResource(): string {
    return ApiEnum.preIngestContributors;
  }

  @Selector()
  static currentTitle(state: PreservationSpaceContributorDepositStateModel): string | undefined {
    if (isNullOrUndefined(state.current)) {
      return undefined;
    }
    return state.current.title;
  }

  @Selector()
  static isReadyToBeDisplayed(state: PreservationSpaceContributorDepositStateModel): boolean {
    return !isNullOrUndefined(state.current);
  }

  @Selector()
  static isLoading(state: PreservationSpaceContributorDepositStateModel): boolean {
    return StoreUtil.isLoadingState(state);
  }
}
