/*-
 * %%----------------------------------------------------------------------------------------------
 * DLCM Technology - DLCM Portal - preservation-space-organizational-unit-preservation-policy.state.ts
 * SPDX-License-Identifier: GPL-2.0-or-later
 * %----------------------------------------------------------------------------------------------%
 * Copyright (C) 2017 - 2022 University of Geneva
 * %----------------------------------------------------------------------------------------------%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-2.0.html>.
 * ----------------------------------------------------------------------------------------------%%
 */

import {OrganizationalUnitPreservationPolicy} from "@admin/models/organizational-unit-preservation-policy.model";
import {Injectable} from "@angular/core";
import {PreservationPolicy} from "@models";
import {
  Action,
  ActionCompletion,
  Actions,
  State,
  StateContext,
  Store,
} from "@ngxs/store";
import {
  PreservationSpaceOrganizationalUnitPreservationPolicyAction,
  preservationSpaceOrganizationalUnitPreservationPolicyActionNameSpace,
} from "@preservation-space/organizational-unit/stores/preservation-policy/preservation-space-organizational-unit-preservation-policy.action";
import {ApiResourceNameEnum} from "@shared/enums/api-resource-name.enum";
import {ApiEnum} from "@shared/enums/api.enum";
import {StateEnum} from "@shared/enums/state.enum";
import {
  Observable,
  of,
} from "rxjs";
import {
  map,
  tap,
} from "rxjs/operators";
import {
  ActionSubActionCompletionsWrapper,
  ApiService,
  BaseSubAction,
  defaultRelation2TiersStateInitValue,
  isEmptyArray,
  isNotNullNorUndefined,
  NotificationService,
  ofSolidifyActionCompleted,
  OverrideDefaultAction,
  Relation2TiersState,
  Relation2TiersStateModel,
  StoreUtil,
} from "solidify-frontend";

export interface PreservationSpaceOrganizationalUnitPreservationPolicyStateModel extends Relation2TiersStateModel<PreservationPolicy> {
}

@Injectable()
@State<PreservationSpaceOrganizationalUnitPreservationPolicyStateModel>({
  name: StateEnum.preservationSpace_organizationalUnit_preservationPolicy,
  defaults: {
    ...defaultRelation2TiersStateInitValue(),
  },
})
export class PreservationSpaceOrganizationalUnitPreservationPolicyState extends Relation2TiersState<PreservationSpaceOrganizationalUnitPreservationPolicyStateModel, PreservationPolicy, OrganizationalUnitPreservationPolicy> {
  constructor(protected readonly _apiService: ApiService,
              protected readonly _store: Store,
              protected readonly _notificationService: NotificationService,
              protected readonly _actions$: Actions) {
    super(_apiService, _store, _notificationService, _actions$, {
      nameSpace: preservationSpaceOrganizationalUnitPreservationPolicyActionNameSpace,
      resourceName: ApiResourceNameEnum.PRES_POLICY,
    });
  }

  protected get _urlResource(): string {
    return ApiEnum.adminOrganizationalUnits;
  }

  @OverrideDefaultAction()
  @Action(PreservationSpaceOrganizationalUnitPreservationPolicyAction.Update)
  update(ctx: StateContext<PreservationSpaceOrganizationalUnitPreservationPolicyStateModel>, action: PreservationSpaceOrganizationalUnitPreservationPolicyAction.Update): Observable<boolean> {
    return super._internalUpdate(ctx, action)
      .pipe(
        tap((isSuccess: boolean) => {
          if (!isSuccess) {
            ctx.dispatch(new PreservationSpaceOrganizationalUnitPreservationPolicyAction.UpdateFail(action, action.parentId));
            return;
          }
          this._updateSubResource(action, ctx)
            .subscribe(success => {
              if (success) {
                ctx.dispatch(new PreservationSpaceOrganizationalUnitPreservationPolicyAction.UpdateSuccess(action, action.parentId));
              } else {
                ctx.dispatch(new PreservationSpaceOrganizationalUnitPreservationPolicyAction.UpdateFail(action, action.parentId));
              }
            });
        }),
      );
  }

  private _updateSubResource(action: PreservationSpaceOrganizationalUnitPreservationPolicyAction.Update, ctx: StateContext<PreservationSpaceOrganizationalUnitPreservationPolicyStateModel>): Observable<boolean> {
    const orgUnitId = action.parentId;

    const listActionSubActionCompletionsWrapper: ActionSubActionCompletionsWrapper[] = [];

    if (action.oldDefaultResId !== action.newDefaultResId) {
      if (isNotNullNorUndefined(action.oldDefaultResId) && action.newResId.includes(action.oldDefaultResId)) {
        listActionSubActionCompletionsWrapper.push({
          action: new PreservationSpaceOrganizationalUnitPreservationPolicyAction.UpdateRelation(orgUnitId, action.oldDefaultResId, {defaultPolicy: false} as OrganizationalUnitPreservationPolicy),
          subActionCompletions: this._getSubActionCompletions(),
        });
      }

      if (isNotNullNorUndefined(action.newDefaultResId)) {
        listActionSubActionCompletionsWrapper.push({
          action: new PreservationSpaceOrganizationalUnitPreservationPolicyAction.UpdateRelation(orgUnitId, action.newDefaultResId, {defaultPolicy: true} as OrganizationalUnitPreservationPolicy),
          subActionCompletions: this._getSubActionCompletions(),
        });
      }
    }
    if (isEmptyArray(listActionSubActionCompletionsWrapper)) {
      return of(true);
    }
    return StoreUtil.dispatchParallelActionAndWaitForSubActionsCompletion(ctx, listActionSubActionCompletionsWrapper).pipe(
      map(result => result.success),
    );
  }

  private _getSubActionCompletions(): Observable<ActionCompletion<BaseSubAction<PreservationSpaceOrganizationalUnitPreservationPolicyAction.UpdateRelation>, Error>>[] | undefined {
    return [
      this._actions$.pipe(ofSolidifyActionCompleted(PreservationSpaceOrganizationalUnitPreservationPolicyAction.UpdateRelationSuccess)),
      this._actions$.pipe(ofSolidifyActionCompleted(PreservationSpaceOrganizationalUnitPreservationPolicyAction.UpdateRelationFail)),
    ];
  }
}
