/*-
 * %%----------------------------------------------------------------------------------------------
 * DLCM Technology - DLCM Portal - shared-image-upload-wrapper.container.ts
 * SPDX-License-Identifier: GPL-2.0-or-later
 * %----------------------------------------------------------------------------------------------%
 * Copyright (C) 2017 - 2022 University of Geneva
 * %----------------------------------------------------------------------------------------------%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-2.0.html>.
 * ----------------------------------------------------------------------------------------------%%
 */

import {
  ChangeDetectionStrategy,
  ChangeDetectorRef,
  Component,
  Input,
} from "@angular/core";
import {FormBuilder} from "@angular/forms";
import {MatDialog} from "@angular/material/dialog";
import {DomSanitizer} from "@angular/platform-browser";
import {ActivatedRoute} from "@angular/router";
import {environment} from "@environments/environment";
import {
  Actions,
  Store,
} from "@ngxs/store";
import {SharedAbstractImageUploadWrapperContainer} from "@shared/components/containers/shared-abstract-image-upload-wrapper/shared-abstract-image-upload-wrapper.container";
import {SharedUploadImageDialogData} from "@shared/components/dialogs/shared-upload-image/shared-upload-image.dialog";
import {IconNameEnum} from "@shared/enums/icon-name.enum";
import {LabelTranslateEnum} from "@shared/enums/label-translate.enum";
import {ResourceLogoState} from "@shared/stores/resource-logo/resource-logo.state";

@Component({
  selector: "dlcm-shared-image-upload-wrapper-container",
  templateUrl: "./shared-image-upload-wrapper.container.html",
  styleUrls: ["./shared-image-upload-wrapper.container.scss"],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class SharedImageUploadWrapperContainer extends SharedAbstractImageUploadWrapperContainer {
  @Input()
  isEditable: boolean = true;

  @Input()
  resourceLogoState: typeof ResourceLogoState;

  @Input()
  preFallbackImage: string | undefined;

  defaultImage: string = `assets/themes/${environment.theme}/toolbar-header-image.svg`;

  @Input()
  defaultIcon: IconNameEnum;

  constructor(protected readonly _store: Store,
              protected readonly _route: ActivatedRoute,
              protected readonly _fb: FormBuilder,
              protected readonly _sanitizer: DomSanitizer,
              protected readonly _cd: ChangeDetectorRef,
              protected readonly _actions$: Actions,
              protected readonly _dialog: MatDialog) {
    super(_store,
      _route,
      _fb,
      _sanitizer,
      _cd,
      _actions$,
      _dialog);
  }

  openModal(): void {
    if (!this.isEditable) {
      return;
    }
    super.openModal();
  }

  protected _defineSharedImageDialogData(): SharedUploadImageDialogData {
    return {
      titleToTranslate: LabelTranslateEnum.uploadLogo,
      imageChangedEvent: undefined,
      isLoadingObs: this.isLoadingObs,
      aspectRatio: 1,
      roundCropped: false,
      resizeToHeight: 300 * 2,
      resizeToWidth: 300 * 2,
    };
  }
}
