/*-
 * %%----------------------------------------------------------------------------------------------
 * DLCM Technology - DLCM Portal - shared-organizational-unit-member.container.ts
 * SPDX-License-Identifier: GPL-2.0-or-later
 * %----------------------------------------------------------------------------------------------%
 * Copyright (C) 2017 - 2022 University of Geneva
 * %----------------------------------------------------------------------------------------------%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-2.0.html>.
 * ----------------------------------------------------------------------------------------------%%
 */

import {
  ChangeDetectionStrategy,
  Component,
  Input,
} from "@angular/core";
import {Enums} from "@enums";
import {OrganizationalUnit} from "@models";
import {SharedAbstractPresentational} from "@shared/components/presentationals/shared-abstract/shared-abstract.presentational";
import {IconNameEnum} from "@shared/enums/icon-name.enum";
import {SecurityService} from "@shared/services/security.service";
import {isNullOrUndefined} from "solidify-frontend";

@Component({
  selector: "dlcm-shared-organizational-unit-member-container",
  templateUrl: "./shared-organizational-unit-member.container.html",
  styleUrls: ["./shared-organizational-unit-member.container.scss"],
  changeDetection: ChangeDetectionStrategy.OnPush,
})

export class SharedOrganizationalUnitMemberContainer extends SharedAbstractPresentational {
  private _organizationalUnit: OrganizationalUnit;

  iconMember: IconNameEnum | undefined = undefined;
  roleName: string | undefined = undefined;

  @Input()
  set organizationalUnit(value: OrganizationalUnit) {
    this._organizationalUnit = value;
    this._computeLogoAndTooltip();
  }

  get organizationalUnit(): OrganizationalUnit {
    return this._organizationalUnit;
  }

  private _computeLogoAndTooltip(): void {
    if (isNullOrUndefined(this.organizationalUnit)) {
      return;
    }
    const role = this._securityService.getRoleInOrgUnit(this.organizationalUnit.resId);
    this.roleName = role?.name;
    switch (role?.resId) {
      case Enums.Role.RoleEnum.MANAGER:
        this.iconMember = IconNameEnum.roleManager;
        break;
      case Enums.Role.RoleEnum.STEWARD:
        this.iconMember = IconNameEnum.roleSteward;
        break;
      case Enums.Role.RoleEnum.APPROVER:
        this.iconMember = IconNameEnum.roleApprover;
        break;
      case Enums.Role.RoleEnum.CREATOR:
        this.iconMember = IconNameEnum.roleCreator;
        break;
      case Enums.Role.RoleEnum.VISITOR:
        this.iconMember = IconNameEnum.roleVisitor;
        break;
      default:
        this.iconMember = undefined;
        break;
    }
  }

  constructor(public readonly _securityService: SecurityService) {
    super();
  }
}
