/*-
 * %%----------------------------------------------------------------------------------------------
 * DLCM Technology - DLCM Portal - shared-admin-research-domain-label.presentational.ts
 * SPDX-License-Identifier: GPL-2.0-or-later
 * %----------------------------------------------------------------------------------------------%
 * Copyright (C) 2017 - 2022 University of Geneva
 * %----------------------------------------------------------------------------------------------%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-2.0.html>.
 * ----------------------------------------------------------------------------------------------%%
 */

import {
  ChangeDetectionStrategy,
  Component,
  Input,
} from "@angular/core";
import {FormBuilder} from "@angular/forms";
import {ResearchDomain} from "@models";
import {SharedAbstractPresentational} from "@shared/components/presentationals/shared-abstract/shared-abstract.presentational";
import {ResearchDomainLabel} from "@shared/models/business/research-domain-label.model";
import {isNullOrUndefined} from "solidify-frontend";

@Component({
  selector: "dlcm-shared-admin-research-domain-label",
  templateUrl: "./shared-admin-research-domain-label.presentational.html",
  styleUrls: ["./shared-admin-research-domain-label.presentational.scss"],
  changeDetection: ChangeDetectionStrategy.OnPush,
})

export class SharedAdminResearchDomainLabelPresentational extends SharedAbstractPresentational {
  private _researchDomain: ResearchDomain;

  private _language: string;

  @Input()
  set researchDomain(value: ResearchDomain) {
    this._researchDomain = value;
    this._computeLabel();
  }

  get researchDomain(): ResearchDomain {
    return this._researchDomain;
  }

  @Input()
  set language(value: string) {
    this._language = value;
    this._computeLabel();
  }

  get language(): string {
    return this._language;
  }

  value: ResearchDomainLabel | undefined;

  private _computeLabel(): void {
    if (isNullOrUndefined(this.language) || isNullOrUndefined(this.researchDomain)) {
      return;
    }
    this.value = this.researchDomain.labels.find(label => label.language.resId === this.language);
  }

  constructor(public readonly _fb: FormBuilder) {
    super();
  }
}
