/*-
 * %%----------------------------------------------------------------------------------------------
 * DLCM Technology - DLCM Portal - shared-doi-menu.presentational.ts
 * SPDX-License-Identifier: GPL-2.0-or-later
 * %----------------------------------------------------------------------------------------------%
 * Copyright (C) 2017 - 2022 University of Geneva
 * %----------------------------------------------------------------------------------------------%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-2.0.html>.
 * ----------------------------------------------------------------------------------------------%%
 */

import {
  ChangeDetectionStrategy,
  Component,
  Input,
  Output,
  ViewChild,
} from "@angular/core";
import {MatMenu} from "@angular/material/menu";
import {environment} from "@environments/environment";
import {SharedAbstractPresentational} from "@shared/components/presentationals/shared-abstract/shared-abstract.presentational";
import {
  BehaviorSubject,
  Observable,
} from "rxjs";
import {
  ClipboardUtil,
  MARK_AS_TRANSLATABLE,
  NotificationService,
  ObservableUtil,
} from "solidify-frontend";

@Component({
  selector: "dlcm-shared-doi-menu",
  templateUrl: "./shared-doi-menu.presentational.html",
  styleUrls: ["./shared-doi-menu.presentational.scss"],
  changeDetection: ChangeDetectionStrategy.OnPush,
  exportAs: "doiMenu",
})
export class SharedDoiMenuPresentational extends SharedAbstractPresentational {
  @Input()
  doi: string;

  @ViewChild(MatMenu, {static: true}) menu: MatMenu;

  @Input()
  mode: "deposit" | "archive";

  private readonly _shortDoiBS: BehaviorSubject<GetShortDoiWrapper | undefined> = new BehaviorSubject<GetShortDoiWrapper | undefined>(undefined);
  @Output("getShortDoi")
  readonly shortDoiObs: Observable<GetShortDoiWrapper | undefined> = ObservableUtil.asObservable(this._shortDoiBS);

  constructor(private readonly _notificationService: NotificationService) {
    super();
  }

  copyShortDoi(): void {
    this._shortDoiBS.next({
      longDoi: this.doi,
      isFullUrl: false,
    });
  }

  copyLongDoi(): void {
    ClipboardUtil.copyStringToClipboard(this.doi);
    this._notificationService.showInformation(MARK_AS_TRANSLATABLE("doi.notification.longDoiCopyToClipboard"));
  }

  copyUrlShortDoi(): void {
    this._shortDoiBS.next({
      longDoi: this.doi,
      isFullUrl: true,
    });
  }

  copyUrlLongDoi(): void {
    ClipboardUtil.copyStringToClipboard(environment.doiLink + this.doi);
    this._notificationService.showInformation(MARK_AS_TRANSLATABLE("doi.notification.urlLongDoiCopyToClipboard"));
  }
}

export interface GetShortDoiWrapper {
  longDoi: string;
  isFullUrl: boolean;
}
