/*-
 * %%----------------------------------------------------------------------------------------------
 * DLCM Technology - DLCM Portal - shared-image-display.presentational.ts
 * SPDX-License-Identifier: GPL-2.0-or-later
 * %----------------------------------------------------------------------------------------------%
 * Copyright (C) 2017 - 2022 University of Geneva
 * %----------------------------------------------------------------------------------------------%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-2.0.html>.
 * ----------------------------------------------------------------------------------------------%%
 */

import {
  ChangeDetectionStrategy,
  Component,
  HostBinding,
  Input,
} from "@angular/core";
import {
  DomSanitizer,
  SafeResourceUrl,
} from "@angular/platform-browser";
import {environment} from "@environments/environment";
import {SharedAbstractPresentational} from "@shared/components/presentationals/shared-abstract/shared-abstract.presentational";
import {isNullOrUndefined} from "solidify-frontend";

@Component({
  selector: "dlcm-shared-image-display",
  templateUrl: "./shared-image-display.presentational.html",
  styleUrls: ["./shared-image-display.presentational.scss"],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class SharedImageDisplayPresentational extends SharedAbstractPresentational {
  imageSanitized: SafeResourceUrl | undefined;

  private _image: string | undefined;

  @Input()
  set image(value: string | undefined) {
    this._image = value;
    this.imageSanitized = this.urlSanitized;
  }

  get image(): string | undefined {
    return this._image;
  }

  @HostBinding("style.width")
  @HostBinding("style.height")
  get size(): string {
    let size;
    switch (this.mode) {
      case ImageDisplayMode.MAIN:
        size = 400;
        break;
      case ImageDisplayMode.IN_TILE:
        size = 200;
        break;
      case ImageDisplayMode.IN_ORDER:
      case ImageDisplayMode.IN_OVERLAY:
        size = 125;
        break;
      case ImageDisplayMode.IN_LIST:
      case ImageDisplayMode.NEXT_FORM_FIELD:
        size = 50;
        break;
      default:
        size = 400;
    }
    return size + "px";
  }

  @HostBinding("class")
  @Input()
  mode: ImageDisplayMode = ImageDisplayMode.MAIN;

  defaultImageArchive: string = `assets/themes/${environment.theme}/toolbar-header-image.svg`;
  displayFallback: boolean = true;
  loading: boolean = true;

  constructor(protected readonly _sanitizer: DomSanitizer) {
    super();
  }

  get urlSanitized(): undefined | SafeResourceUrl {
    if (isNullOrUndefined(this.image)) {
      return undefined;
    } else {
      return this._sanitizer.bypassSecurityTrustResourceUrl(this.image);
    }
  }

  determineDisplayFallback(image: HTMLImageElement): void {
    this.loading = false;
    if (image.width > 0) {
      this.displayFallback = false;
    }
  }

  unableToLoad(image: HTMLImageElement): void {
    this.loading = false;
    this.displayFallback = true;
  }
}

export type ImageDisplayMode = "MAIN" | "IN_TILE" | "IN_ORDER" | "IN_LIST" | "NEXT_FORM_FIELD";
export const ImageDisplayMode = {
  UPLOAD: "UPLOAD" as ImageDisplayMode,
  MAIN: "MAIN" as ImageDisplayMode,
  IN_TILE: "IN_TILE" as ImageDisplayMode,
  IN_ORDER: "IN_ORDER" as ImageDisplayMode,
  IN_OVERLAY: "IN_OVERLAY" as ImageDisplayMode,
  IN_LIST: "IN_LIST" as ImageDisplayMode,
  NEXT_FORM_FIELD: "NEXT_FORM_FIELD" as ImageDisplayMode,
};
