/*-
 * %%----------------------------------------------------------------------------------------------
 * DLCM Technology - DLCM Portal - shared-avatar.presentational.ts
 * SPDX-License-Identifier: GPL-2.0-or-later
 * %----------------------------------------------------------------------------------------------%
 * Copyright (C) 2017 - 2022 University of Geneva
 * %----------------------------------------------------------------------------------------------%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-2.0.html>.
 * ----------------------------------------------------------------------------------------------%%
 */

import {
  ChangeDetectionStrategy,
  Component,
  HostBinding,
  Input,
} from "@angular/core";
import {
  DomSanitizer,
  SafeResourceUrl,
} from "@angular/platform-browser";
import {SharedAbstractPresentational} from "@app/shared/components/presentationals/shared-abstract/shared-abstract.presentational";
import {User} from "@models";
import {isNullOrUndefined} from "solidify-frontend";

@Component({
  selector: "dlcm-shared-avatar",
  templateUrl: "./shared-avatar.presentational.html",
  styleUrls: ["./shared-avatar.presentational.scss"],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class SharedAvatarPresentational extends SharedAbstractPresentational {
  private _user: User;

  @Input()
  set user(value: User) {
    this._user = value;
    this.computeInitial();
  }

  get user(): User {
    return this._user;
  }

  @HostBinding("class.is-photo")
  private _photoUserSanitize: SafeResourceUrl | undefined;

  @Input()
  set photoUser(value: string) {
    if (isNullOrUndefined(value)) {
      this._photoUserSanitize = undefined;
      return;
    }
    this._photoUserSanitize = this.sanitizeUrl(value);
  }

  get photoUserSanitize(): SafeResourceUrl {
    return this._photoUserSanitize;
  }

  private readonly _DEFAULT_INITIAL: string = "";

  initial: string = this._DEFAULT_INITIAL;

  constructor(private readonly _sanitizer: DomSanitizer) {
    super();
  }

  computeInitial(): void {
    if (isNullOrUndefined(this._user)) {
      this.initial = this._DEFAULT_INITIAL;
    } else {
      this.initial = this._user.firstName.substring(0, 1) + this._user.lastName.substring(0, 1);
    }
  }

  sanitizeUrl(url: string | undefined): undefined | SafeResourceUrl {
    if (isNullOrUndefined(url)) {
      return undefined;
    } else {
      return this._sanitizer.bypassSecurityTrustResourceUrl(url);
    }
  }
}
