/*-
 * %%----------------------------------------------------------------------------------------------
 * DLCM Technology - DLCM Portal - shared-institution-overlay.presentational.ts
 * SPDX-License-Identifier: GPL-2.0-or-later
 * %----------------------------------------------------------------------------------------------%
 * Copyright (C) 2017 - 2022 University of Geneva
 * %----------------------------------------------------------------------------------------------%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-2.0.html>.
 * ----------------------------------------------------------------------------------------------%%
 */

import {
  ChangeDetectionStrategy,
  Component,
} from "@angular/core";
import {Institution} from "@models";
import {ImageDisplayMode} from "@shared/components/presentationals/shared-image-display/shared-image-display.presentational";
import {
  overlayAnimation,
  SharedResourceLogoOverlayPresentational,
} from "@shared/components/presentationals/shared-resource-logo-overlay/shared-resource-logo-overlay.presentational";
import {IconNameEnum} from "@shared/enums/icon-name.enum";
import {SharedInstitutionAction} from "@shared/stores/institution/shared-institution.action";
import {SharedInstitutionState} from "@shared/stores/institution/shared-institution.state";
import {ResourceLogoNameSpace} from "@shared/stores/resource-logo/resource-logo-namespace.model";
import {ResourceLogoState} from "@shared/stores/resource-logo/resource-logo.state";
import {isNotNullNorUndefined} from "solidify-frontend";

@Component({
  selector: "dlcm-shared-institution-overlay",
  templateUrl: "./shared-institution-overlay.presentational.html",
  styleUrls: ["./shared-institution-overlay.presentational.scss"],
  changeDetection: ChangeDetectionStrategy.OnPush,
  animations: [overlayAnimation],
})
export class SharedInstitutionOverlayPresentational extends SharedResourceLogoOverlayPresentational<Institution> {
  logoActionNameSpace: ResourceLogoNameSpace = SharedInstitutionAction;
  logoState: typeof ResourceLogoState = SharedInstitutionState as any;

  get isLogoPresent(): boolean {
    return isNotNullNorUndefined(this.data?.logo);
  }

  get iconNameEnum(): typeof IconNameEnum {
    return IconNameEnum;
  }

  get imageDisplayMode(): typeof ImageDisplayMode {
    return ImageDisplayMode;
  }
}
