/*-
 * %%----------------------------------------------------------------------------------------------
 * DLCM Technology - DLCM Portal - shared-person-overlay.presentational.ts
 * SPDX-License-Identifier: GPL-2.0-or-later
 * %----------------------------------------------------------------------------------------------%
 * Copyright (C) 2017 - 2022 University of Geneva
 * %----------------------------------------------------------------------------------------------%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-2.0.html>.
 * ----------------------------------------------------------------------------------------------%%
 */

import {
  ChangeDetectionStrategy,
  Component,
} from "@angular/core";
import {
  Person,
  User,
} from "@models";
import {ImageDisplayMode} from "@shared/components/presentationals/shared-image-display/shared-image-display.presentational";
import {overlayAnimation} from "@shared/components/presentationals/shared-resource-logo-overlay/shared-resource-logo-overlay.presentational";
import {IconNameEnum} from "@shared/enums/icon-name.enum";
import {LabelTranslateEnum} from "@shared/enums/label-translate.enum";
import {SharedPersonAction} from "@shared/stores/person/shared-person.action";
import {SharedPersonState} from "@shared/stores/person/shared-person.state";
import {ResourceLogoNameSpace} from "@shared/stores/resource-logo/resource-logo-namespace.model";
import {
  AbstractOverlayPresentational,
  isNotNullNorUndefined,
  isNullOrUndefined,
} from "solidify-frontend";

@Component({
  selector: "dlcm-shared-person-overlay",
  templateUrl: "./shared-person-overlay.presentational.html",
  styleUrls: ["./shared-person-overlay.presentational.scss"],
  changeDetection: ChangeDetectionStrategy.OnPush,
  animations: [overlayAnimation],
})
export class SharedPersonOverlayPresentational extends AbstractOverlayPresentational<Person> {
  data: Person;

  personAvatarActionNameSpace: ResourceLogoNameSpace = SharedPersonAction;
  personState: typeof SharedPersonState = SharedPersonState;

  get user(): User {
    if (isNullOrUndefined(this.data)) {
      return this.data;
    }
    return this.data as User;
  }

  get insitutionsName(): string[] {
    if (isNullOrUndefined(this.data.institutions)) {
      return [];
    }
    return this.data.institutions.map(i => i.name);
  }

  get isAvatarPresent(): boolean {
    return isNotNullNorUndefined(this.data?.avatar);
  }

  get iconNameEnum(): typeof IconNameEnum {
    return IconNameEnum;
  }

  get imageDisplayMode(): typeof ImageDisplayMode {
    return ImageDisplayMode;
  }

  get labelTranslateEnum(): typeof LabelTranslateEnum {
    return LabelTranslateEnum;
  }
}
