/*-
 * %%----------------------------------------------------------------------------------------------
 * DLCM Technology - DLCM Portal - orcid.service.ts
 * SPDX-License-Identifier: GPL-2.0-or-later
 * %----------------------------------------------------------------------------------------------%
 * Copyright (C) 2017 - 2022 University of Geneva
 * %----------------------------------------------------------------------------------------------%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-2.0.html>.
 * ----------------------------------------------------------------------------------------------%%
 */

import {Injectable} from "@angular/core";
import {AppSystemPropertyState} from "@app/stores/system-property/app-system-property.state";
import {environment} from "@environments/environment";
import {Store} from "@ngxs/store";
import {ApiEnum} from "@shared/enums/api.enum";
import {
  AbstractBaseService,
  ApiService,
  MemoizedUtil,
} from "solidify-frontend";

@Injectable({
  providedIn: "root",
})
export class OrcidService extends AbstractBaseService {
  constructor(private readonly _apiService: ApiService,
              private readonly _store: Store) {
    super();
  }

  public startOrcidAuth(): void {
    const startOrcidAuthUrl = ApiEnum.adminOrcid + "/start-orcid-auth";
    const originUrl: string = window.location.href;
    let orcidQueryParam = environment.orcidQueryParam + "=true";
    if (originUrl.includes("?")) {
      orcidQueryParam = "&" + orcidQueryParam;
    } else {
      orcidQueryParam = "?" + orcidQueryParam;
    }

    this._apiService.get<string>(startOrcidAuthUrl, {}, {originUrl: originUrl + orcidQueryParam})
      .subscribe(val => this._getOrcid(val["authTransactionId"]));
  }

  private _getOrcid(authTransactionId: string): void {
    const authorizeUrl: string = environment.orcidAuthorizeUrl;
    const clientId: string = MemoizedUtil.selectSnapshot(this._store, AppSystemPropertyState, state => state.current.orcidClientId);
    const redirectUri: string = ApiEnum.adminOrcid + "/landing?authTransactionId=" + authTransactionId;
    window.location.href = authorizeUrl
      + "?client_id=" + clientId
      + "&response_type=code"
      + "&scope=/authenticate"
      + "&redirect_uri=" + redirectUri;
  }
}
