/*-
 * %%----------------------------------------------------------------------------------------------
 * DLCM Technology - DLCM Portal - app.action.ts
 * SPDX-License-Identifier: GPL-2.0-or-later
 * %----------------------------------------------------------------------------------------------%
 * Copyright (C) 2017 - 2022 University of Geneva
 * %----------------------------------------------------------------------------------------------%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-2.0.html>.
 * ----------------------------------------------------------------------------------------------%%
 */

import {GetShortDoiWrapper} from "@shared/components/presentationals/shared-doi-menu/shared-doi-menu.presentational";
import {
  BaseAction,
  BaseSubActionFail,
  BaseSubActionSuccess,
  SolidifyAppAction,
} from "solidify-frontend";
import {StateEnum} from "../shared/enums/state.enum";

const state = StateEnum.application;

export namespace AppExtendAction {
  export class LoadCart extends BaseAction {
    static readonly type: string = `[${state}] Load Cart`;
  }

  export class StartPollingOrder extends BaseAction {
    static readonly type: string = `[${state}] Start Polling Order`;
  }

  export class StartPollingNotification extends BaseAction {
    static readonly type: string = `[${state}] Start Polling Notification`;
  }

  export class UpdateNotificationInbox {
    static readonly type: string = `[${state}] Update Notification Inbox`;
  }

  export class InitiateNewLogin extends BaseAction {
    static readonly type: string = `[${state}] Initiate New Login`;
  }

  export class GetShortDoi extends BaseAction {
    static readonly type: string = `[${state}] Get Short DOI`;

    constructor(public doiWrapper: GetShortDoiWrapper) {
      super();
    }
  }

  export class GetShortDoiSuccess extends BaseSubActionSuccess<GetShortDoi> {
    static readonly type: string = `[${state}] Get Short DOI Success`;

    constructor(public parent: GetShortDoi, public shortDoi: string) {
      super(parent);
    }
  }

  export class GetShortDoiFail extends BaseSubActionFail<GetShortDoi> {
    static readonly type: string = `[${state}] Get Short DOI Fail`;

    constructor(public parent: GetShortDoi) {
      super(parent);
    }
  }
}

export const appActionNameSpace: (typeof SolidifyAppAction & typeof AppExtendAction) = {...SolidifyAppAction, ...AppExtendAction};
