/*-
 * %%----------------------------------------------------------------------------------------------
 * DLCM Technology - DLCM Portal - app-banner.state.ts
 * SPDX-License-Identifier: GPL-2.0-or-later
 * %----------------------------------------------------------------------------------------------%
 * Copyright (C) 2017 - 2022 University of Geneva
 * %----------------------------------------------------------------------------------------------%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-2.0.html>.
 * ----------------------------------------------------------------------------------------------%%
 */

import {Injectable} from "@angular/core";
import {AppBannerAction} from "@app/stores/banner/app-banner.action";
import {
  Action,
  Actions,
  State,
  StateContext,
  Store,
} from "@ngxs/store";
import {LabelTranslateEnum} from "@shared/enums/label-translate.enum";
import {StateEnum} from "@shared/enums/state.enum";
import {
  ApiService,
  BannerColorEnum,
  BaseStateModel,
  BasicState,
  defaultBaseStateInitValue,
  NotificationService,
  SolidifyObject,
} from "solidify-frontend";

export interface AppBannerStateModel extends BaseStateModel {
  color: BannerColorEnum | undefined;
  message: string | undefined;
  parameters: SolidifyObject;
  display: boolean;
}

@Injectable()
@State<AppBannerStateModel>({
  name: StateEnum.application_banner,
  defaults: {
    ...defaultBaseStateInitValue(),
    color: undefined,
    message: undefined,
    parameters: {},
    display: false,
  },
})
export class AppBannerState extends BasicState<AppBannerStateModel> {
  constructor(protected readonly _apiService: ApiService,
              protected readonly _store: Store,
              protected readonly _notificationService: NotificationService,
              protected readonly _actions$: Actions) {
    super();
  }

  @Action(AppBannerAction.Show)
  show(ctx: StateContext<AppBannerStateModel>, action: AppBannerAction.Show): void {
    ctx.patchState({
      message: action.message,
      parameters: action.parameters,
      color: action.color,
      display: true,
    });
  }

  @Action(AppBannerAction.ShowInEditMode)
  showInEditMode(ctx: StateContext<AppBannerStateModel>, action: AppBannerAction.ShowInEditMode): void {
    ctx.dispatch(new AppBannerAction.Show(LabelTranslateEnum.youAreInEditMode, BannerColorEnum.warn));
  }

  @Action(AppBannerAction.Hide)
  hide(ctx: StateContext<AppBannerStateModel>, action: AppBannerAction.Hide): void {
    ctx.patchState({
      message: undefined,
      color: undefined,
      display: false,
    });
  }
}
