/*-
 * %%----------------------------------------------------------------------------------------------
 * DLCM Technology - DLCM Portal - environment.defaults.ts
 * SPDX-License-Identifier: GPL-2.0-or-later
 * %----------------------------------------------------------------------------------------------%
 * Copyright (C) 2017 - 2022 University of Geneva
 * %----------------------------------------------------------------------------------------------%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-2.0.html>.
 * ----------------------------------------------------------------------------------------------%%
 */

// This file should contains all the defaults settings shared in all environment files
// If you want to override properties for specific environment, do it in these files

import {ErrorBackendKeyEnum} from "@app/shared/enums/error-backend-key.enum";
import {ThemeEnum} from "@app/shared/enums/theme.enum";
import {Enums} from "@enums";
import {
  AppRoutesEnum,
  RoutesEnum,
} from "@shared/enums/routes.enum";
import {ViewModeTableEnum} from "@shared/enums/view-mode-table.enum";
import {defaultSolidifyEnvironment} from "solidify-frontend";
import {DlcmEnvironment} from "./environment.defaults.model";

export const defaultEnvironment: DlcmEnvironment = {
  ...defaultSolidifyEnvironment,
  appTitle: "DLCM - Portal",
  appDescription: "Platform for archiving research data",
  forceServiceWorker: false,
  listTagsComponentsWhereClickAllowToEnterInEditMode: [
    "dlcm-shared-table-person-orgunit-role-container",
    "dlcm-shared-table-orgunit-container",
  ],
  defaultLanguage: Enums.Language.LanguageEnum.en,
  appLanguages: [Enums.Language.LanguageEnum.en, Enums.Language.LanguageEnum.fr],
  appLanguagesTranslate: Enums.Language.LanguageEnumTranslate,
  appThemes: [ThemeEnum.dlcm, ThemeEnum.yareta, ThemeEnum.centella, ThemeEnum.olos],
  appThemesTranslate: [
    {key: ThemeEnum.dlcm, value: "DLCM"},
    {key: ThemeEnum.yareta, value: "Yareta"},
    {key: ThemeEnum.olos, value: "Olos"},
    {key: ThemeEnum.centella, value: "Centella"},
  ],
  theme: ThemeEnum.dlcm,
  routeHomePage: RoutesEnum.homePage,
  routeSegmentEdit: AppRoutesEnum.edit,
  displayPrivacyPolicyAndTermsOfUseApprovalDialog: false,
  privacyPolicyLink: "",
  termsOfUseLink: "",
  listNotificationToHideInProfile: [],

  // Base URL For Module Applications (override by AppAction.LoadModules)
  admin: "http://localhost:16105/dlcm/admin",

  // Documentation
  documentationTocApisGuide: "DLCM-APIs-toc.html",
  documentationTocIntegrationGuide: "DLCM-IntegrationGuide-toc.html",
  documentationTocToolsGuide: "DLCM-ToolsGuide-toc.html",
  documentationTocUserGuidePath: undefined,
  documentationTocUserGuide: undefined,

  // Orcid
  orcidQueryParam: "orcid",
  orcidAuthorizeUrl: "https://orcid.org/oauth/authorize",

  // Access request
  accessRequestRoute: "accessRequest",

  institutionUrl: "https://www.unige.ch/",

  // === Solidify Upload Environment ===
  errorUploadDuplicateFile: ErrorBackendKeyEnum.UPLOAD_DUPLICATE_DATA_FILES,

  // Home
  defaultHomeViewModeTableEnum: ViewModeTableEnum.tiles,
  defaultPageSizeHomePage: 10,
  defaultHomeOrgUnitSize: 1000,
  carouselUrl: undefined,
  frequencyChangeCarouselTileInSecond: 5,
  twitterAccount: "dlcm_ch",
  twitterTweetToDisplay: 4,

  urlNationalArchivePronom: "https://www.nationalarchives.gov.uk/PRONOM/",

  doiLink: "https://doi.org/",
  oaiProviderUrlEnd: "/oai-provider/oai?verb=Identify&smartView=dlcm_oai2.xsl",

  // Polling
  refreshTabStatusCounterIntervalInSecond: 60,
  refreshOrderAvailableIntervalInSecond: 5,
  refreshNotificationInboxAvailableIntervalInSecond: 60,
  refreshDepositSubmittedIntervalInSecond: 2,
  refreshSipProcessIntervalInSecond: 2,

  // Errors
  httpErrorKeyToSkipInErrorHandler: [
    ErrorBackendKeyEnum.UPLOAD_DUPLICATE_DATA_FILES,
  ],

  archivalStorageName: [
    "File",
    "S2",
  ],
  defaultStorageIndex: 0,
  fileSizeLimitForChecksumGenerationInMegabytes: 100,

  listFacetUseOperatorAnd: [Enums.Facet.Name.CREATOR_FACET],
};
